@@ -23,7 +23,8 @@
 #include "config.h"
 #include "dem/CDemDraw.h"
 #include "dem/CDemList.h"
-#include "gis/CGisWidget.h"
+#include "gis/CGisDatabase.h"
+#include "gis/CGisWorkspace.h"
 #include "gis/IGisLine.h"
 #include "gis/WptIcons.h"
 #include "gis/db/CSetupWorkspace.h"
@@ -62,6 +63,8 @@
 
 CMainWindow * CMainWindow::pSelf = nullptr;
 
+QMutex CMainWindow::mutex(QMutex::NonRecursive);
+
 CMainWindow::CMainWindow()
     : id(qrand())
 {
@@ -74,27 +77,68 @@ CMainWindow::CMainWindow()
 
     initWptIcons();
 
-    IUnit::self().setUnitType((IUnit::type_e)cfg.value("MainWindow/units",IUnit::eTypeMetric).toInt(), this);
+    IUnit::setUnitType((IUnit::type_e)cfg.value("MainWindow/units",IUnit::eTypeMetric).toInt(), this);
+    IUnit::setSlopeMode((IUnit::slope_mode_e)cfg.value("Units/slopeMode", IUnit::eSlopeDegrees).toInt());
+
+    QByteArray tz;
+    IUnit::tz_mode_e tzmode;
+    bool useShortFormat;
+    tz = cfg.value("Units/timezone", "UTC").toByteArray();
+    tzmode = (IUnit::tz_mode_e)cfg.value("Units/timezone/mode", IUnit::eTZUtc).toInt();
+    useShortFormat = cfg.value("Units/time/useShortFormat", false).toBool();
+    IUnit::setTimeZoneSetup(tzmode, tz, useShortFormat);
+
+    IUnit::coord_format_e coordFormat;
+    coordFormat = (IUnit::coord_format_e)cfg.value("Units/coordFormat", IUnit::eCoordFormat1).toInt();
+    IUnit::setCoordFormat(coordFormat);
+
     CKnownExtension::init(IUnit::self());
     CActivityTrk::init();
 
-    gisWidget = new CGisWidget(menuProject, this);
-    dockGis->setWidget(gisWidget);
+    widgetGisWorkspace = new CGisWorkspace(menuProject, this);
+    dockWorkspace->setWidget(widgetGisWorkspace);
+
+    widgetGisDatabase = new CGisDatabase(this);
+    dockDatabase->setWidget(widgetGisDatabase);
 
     // start ---- restore window geometry -----
-    if ( cfg.contains("MainWindow/geometry"))
+    cfg.beginGroup("MainWindow");
+    if ( cfg.contains("geometry"))
     {
-        restoreGeometry(cfg.value("MainWindow/geometry").toByteArray());
+        restoreGeometry(cfg.value("geometry").toByteArray());
     }
     else
     {
         QTimer::singleShot(500, this, SLOT(showMaximized()));
     }
 
-    if ( cfg.contains("MainWindow/state"))
+    if ( cfg.contains("state"))
     {
-        restoreState(cfg.value("MainWindow/state").toByteArray());
+        restoreState(cfg.value("state").toByteArray());
     }
+
+    if (cfg.contains("displaymode"))
+    {
+        displayMode = static_cast<Qt::WindowStates>(cfg.value("displaymode").toInt());
+        if (displayMode == Qt::WindowFullScreen)
+        {
+            displayMode = Qt::WindowMaximized;
+        }
+    }
+
+    if (cfg.contains("dockstate"))
+    {
+        dockStates = cfg.value("dockstate").toByteArray();
+    }
+
+    menuVisible = cfg.value("menuvisible",false).toBool();
+
+    if(windowState() == Qt::WindowFullScreen)
+    {
+        displayRegular();
+    }
+    cfg.endGroup();
+
     // end ---- restore window geometry -----
 
     connect(actionAbout,                 &QAction::triggered,            this,      &CMainWindow::slotAbout);
@@ -107,6 +151,7 @@ CMainWindow::CMainWindow()
     connect(actionPOIText,               &QAction::changed,              this,      &CMainWindow::slotUpdateCurrentWidget);
     connect(actionMapToolTip,            &QAction::changed,              this,      &CMainWindow::slotUpdateCurrentWidget);
     connect(actionNightDay,              &QAction::changed,              this,      &CMainWindow::slotUpdateCurrentWidget);
+    connect(actionMinMaxTrackValues,     &QAction::changed,              this,      &CMainWindow::slotUpdateCurrentWidget);
     connect(actionProfileIsWindow,       &QAction::toggled,              this,      &CMainWindow::slotSetProfileMode);
     connect(actionSetupMapFont,          &QAction::triggered,            this,      &CMainWindow::slotSetupMapFont);
     connect(actionSetupMapBackground,    &QAction::triggered,            this,      &CMainWindow::slotSetupMapBackground);
@@ -120,7 +165,7 @@ CMainWindow::CMainWindow()
     connect(actionSetupCoordFormat,      &QAction::triggered,            this,      &CMainWindow::slotSetupCoordFormat);
     connect(actionSetupToolbar,          &QAction::triggered,            this,      &CMainWindow::slotSetupToolbar);
     connect(actionImportDatabase,        &QAction::triggered,            this,      &CMainWindow::slotImportDatabase);
-    connect(actionSaveGISData,           &QAction::triggered,            gisWidget, &CGisWidget::slotSaveAll);
+    connect(actionSaveGISData,           &QAction::triggered,            widgetGisWorkspace, &CGisWorkspace::slotSaveAll);
     connect(actionLoadGISData,           &QAction::triggered,            this,      &CMainWindow::slotLoadGISData);
     connect(actionVrtBuilder,            &QAction::triggered,            this,      &CMainWindow::slotBuildVrt);
     connect(actionStoreView,             &QAction::triggered,            this,      &CMainWindow::slotStoreView);
@@ -131,8 +176,8 @@ CMainWindow::CMainWindow()
     connect(actionSetupWaypointIcons,    &QAction::triggered,            this,      &CMainWindow::slotSetupWptIcons);
     connect(actionCloseTab,              &QAction::triggered,            this,      &CMainWindow::slotCloseTab);
     connect(actionToggleDocks,           &QAction::triggered,            this,      &CMainWindow::slotToggleDocks);
+    connect(actionFullScreen,            &QAction::triggered,            this,      &CMainWindow::slotFullScreen);
     connect(tabWidget,                   &QTabWidget::tabCloseRequested, this,      &CMainWindow::slotTabCloseRequest);
-
     connect(tabWidget,                   &QTabWidget::currentChanged,    this,      &CMainWindow::slotCurrentTabCanvas);
     connect(tabMaps,                     &QTabWidget::currentChanged,    this,      &CMainWindow::slotCurrentTabMaps);
     connect(tabDem,                      &QTabWidget::currentChanged,    this,      &CMainWindow::slotCurrentTabDem);
@@ -146,9 +191,7 @@ CMainWindow::CMainWindow()
 
     for(const QString &name : names)
     {
-        CCanvas * view = new CCanvas(tabWidget, name);
-        tabWidget->addTab(view, view->objectName());
-        connect(view, &CCanvas::sigMousePosition, this, &CMainWindow::slotMousePosition);
+        CCanvas * view = addView(name);
 
         cfg.beginGroup(name);
         view->loadConfig(cfg);
@@ -156,40 +199,28 @@ CMainWindow::CMainWindow()
     }
     if(names.isEmpty())
     {
-        CCanvas * view = new CCanvas(tabWidget, QString());
+        CCanvas * view = addView(QString());
+        // call just to setup default values
         view->loadConfig(cfg);
-        tabWidget->addTab(view, view->objectName());
-        connect(view, &CCanvas::sigMousePosition, this, &CMainWindow::slotMousePosition);
     }
     cfg.endGroup(); // Views
     testForNoView();
 
     CCanvas::gisLayerOpacity = cfg.value("gisLayerOpacity",1.0).toFloat();
-    gisWidget->setOpacity(CCanvas::gisLayerOpacity);
+    widgetGisWorkspace->setOpacity(CCanvas::gisLayerOpacity);
 
     actionShowScale->setChecked(cfg.value("isScaleVisible", true).toBool());
     actionShowGrid->setChecked(cfg.value("isGridVisible", false).toBool());
     actionPOIText->setChecked(cfg.value("POIText", true).toBool());
     actionMapToolTip->setChecked(cfg.value("MapToolTip", true).toBool());
     actionNightDay->setChecked(cfg.value("isNight", false).toBool());
+    actionMinMaxTrackValues->setChecked(cfg.value("MinMaxTrackValues", false).toBool());
     actionFlipMouseWheel->setChecked(cfg.value("flipMouseWheel", false).toBool());
     actionProfileIsWindow->setChecked(cfg.value("profileIsWindow", false).toBool());
     mapFont = cfg.value("mapFont", font()).value<QFont>();
     tabWidget->setCurrentIndex(cfg.value("visibleCanvas",0).toInt());
     cfg.endGroup(); // Canvas
 
-    QByteArray tz;
-    IUnit::tz_mode_e tzmode;
-    bool useShortFormat;
-    tz = cfg.value("Units/timezone", "UTC").toByteArray();
-    tzmode = (IUnit::tz_mode_e)cfg.value("Units/timezone/mode", IUnit::eTZUtc).toInt();
-    useShortFormat = cfg.value("Units/time/useShortFormat", false).toBool();
-
-    IUnit::setTimeZoneSetup(tzmode, tz, useShortFormat);
-
-    IUnit::coord_format_e coordFormat;
-    coordFormat = (IUnit::coord_format_e)cfg.value("Units/coordFormat", IUnit::eCoordFormat1).toInt();
-    IUnit::setCoordFormat(coordFormat);
 
 
     QStatusBar * status = statusBar();
@@ -208,12 +239,13 @@ CMainWindow::CMainWindow()
 
     docks << dockMaps
           << dockDem
-          << dockGis
+          << dockWorkspace
+          << dockDatabase
           << dockRte;
 
-    if (cfg.contains(QStringLiteral("MainWindow/activedocks")))
+    if (cfg.contains("MainWindow/activedocks"))
     {
-        const QStringList & dockNames = cfg.value(QStringLiteral("MainWindow/activedocks")).toStringList();
+        const QStringList & dockNames = cfg.value("MainWindow/activedocks").toStringList();
         for(QDockWidget * const & dock : docks)
         {
             if(dockNames.contains(dock->objectName()))
@@ -230,35 +262,41 @@ CMainWindow::CMainWindow()
 
 
     QAction * actionToggleToolBar = toolBar->toggleViewAction();
-    actionToggleToolBar->setObjectName(QStringLiteral("actionToggleToolBar"));
-    actionToggleToolBar->setIcon(QIcon(QStringLiteral(":/icons/32x32/ToolBar.png")));
+    actionToggleToolBar->setObjectName("actionToggleToolBar");
+    actionToggleToolBar->setIcon(QIcon(":/icons/32x32/ToolBar.png"));
     menuWindow->insertAction(actionSetupToolbar,actionToggleToolBar);
 
     QAction * actionToggleMaps = dockMaps->toggleViewAction();
-    actionToggleMaps->setObjectName(QStringLiteral("actionToggleMaps"));
-    actionToggleMaps->setIcon(QIcon(QStringLiteral(":/icons/32x32/ToggleMaps.png")));
+    actionToggleMaps->setObjectName("actionToggleMaps");
+    actionToggleMaps->setIcon(QIcon(":/icons/32x32/ToggleMaps.png"));
     menuWindow->insertAction(actionSetupToolbar,actionToggleMaps);
 
     QAction * actionToggleDem = dockDem->toggleViewAction();
-    actionToggleDem->setObjectName(QStringLiteral("actionToggleDem"));
-    actionToggleDem->setIcon(QIcon(QStringLiteral(":/icons/32x32/ToggleDem.png")));
+    actionToggleDem->setObjectName("actionToggleDem");
+    actionToggleDem->setIcon(QIcon(":/icons/32x32/ToggleDem.png"));
     menuWindow->insertAction(actionSetupToolbar,actionToggleDem);
 
-    QAction * actionToggleGis = dockGis->toggleViewAction();
-    actionToggleGis->setObjectName(QStringLiteral("actionToggleGis"));
-    actionToggleGis->setIcon(QIcon(QStringLiteral(":/icons/32x32/ToggleGis.png")));
-    menuWindow->insertAction(actionSetupToolbar,actionToggleGis);
+    QAction * actionToggleWorkspace = dockWorkspace->toggleViewAction();
+    actionToggleWorkspace->setObjectName("actionToggleWorkspace");
+    actionToggleWorkspace->setIcon(QIcon(":/icons/32x32/ToggleGis.png"));
+    menuWindow->insertAction(actionSetupToolbar,actionToggleWorkspace);
+
+    QAction * actionToggleDatabase = dockDatabase->toggleViewAction();
+    actionToggleDatabase->setObjectName("actionToggleDatabase");
+    actionToggleDatabase->setIcon(QIcon(":/icons/32x32/ToggleDatabase.png"));
+    menuWindow->insertAction(actionSetupToolbar,actionToggleDatabase);
 
     QAction * actionToggleRte = dockRte->toggleViewAction();
-    actionToggleRte->setObjectName(QStringLiteral("actionToggleRte"));
-    actionToggleRte->setIcon(QIcon(QStringLiteral(":/icons/32x32/ToggleRouter.png")));
+    actionToggleRte->setObjectName("actionToggleRte");
+    actionToggleRte->setIcon(QIcon(":/icons/32x32/ToggleRouter.png"));
     menuWindow->insertAction(actionSetupToolbar,actionToggleRte);
 
+
     menuWindow->insertSeparator(actionSetupToolbar);
 
-    QAction * separator = new QAction(QStringLiteral("---------------"),this);
+    QAction * separator = new QAction("---------------",this);
     separator->setSeparator(true);
-    separator->setObjectName(QStringLiteral("separator"));
+    separator->setObjectName("separator");
 
     QList<QAction *> availableActions;
     availableActions << separator
@@ -272,6 +310,7 @@ CMainWindow::CMainWindow()
                      << actionPOIText
                      << actionNightDay
                      << actionMapToolTip
+                     << actionMinMaxTrackValues
                      << actionSetupDEMPaths
                      << actionAbout
                      << actionHelp
@@ -301,14 +340,16 @@ CMainWindow::CMainWindow()
                      << actionSetupToolbar
                      << actionToggleMaps
                      << actionToggleDem
-                     << actionToggleGis
+                     << actionToggleWorkspace
+                     << actionToggleDatabase
                      << actionToggleRte
                      << actionToggleDocks
-                     << actionToggleToolBar;
+                     << actionToggleToolBar
+                     << actionFullScreen;
 
-    QAction * separator1 = new QAction(QStringLiteral("---------------"),this);
+    QAction * separator1 = new QAction("---------------",this);
     separator1->setSeparator(true);
-    separator1->setObjectName(QStringLiteral("separator"));
+    separator1->setObjectName("separator");
 
     QList<QAction *> defaultActions;
     defaultActions << actionSearchGoogle
@@ -321,20 +362,33 @@ CMainWindow::CMainWindow()
                    << actionPOIText
                    << actionNightDay
                    << actionMapToolTip
+                   << actionMinMaxTrackValues
                    << actionProfileIsWindow
                    << separator1
                    << actionSetupToolbar
                    << actionToggleMaps
                    << actionToggleDem
-                   << actionToggleGis
+                   << actionToggleWorkspace
+                   << actionToggleDatabase
                    << actionToggleRte
-                   << actionToggleDocks;
+                   << actionToggleDocks
+                   << actionFullScreen;
 
     toolBarConfig = new CToolBarConfig(this, toolBar, availableActions, defaultActions);
     toolBarConfig->loadSettings();
 
     prepareMenuForMac();
 
+    // make sure all actions that have a shortcut are available even when menu and toolbar are not visible
+    for (QAction * action : availableActions)
+    {
+        if (!action->shortcuts().isEmpty())
+        {
+            addAction(action);
+        }
+    }
+
+
     loadGISData(qlOpts->arguments);
 
     QTimer::singleShot(100, this, SLOT(slotSanityTest()));
@@ -345,7 +399,8 @@ void CMainWindow::prepareMenuForMac()
     toolBar->toggleViewAction()->setMenuRole(QAction::NoRole);
     dockMaps->toggleViewAction()->setMenuRole(QAction::NoRole);
     dockDem->toggleViewAction()->setMenuRole(QAction::NoRole);
-    dockGis->toggleViewAction()->setMenuRole(QAction::NoRole);
+    dockWorkspace->toggleViewAction()->setMenuRole(QAction::NoRole);
+    dockDatabase->toggleViewAction()->setMenuRole(QAction::NoRole);
     dockRte->toggleViewAction()->setMenuRole(QAction::NoRole);
 }
 
@@ -354,15 +409,21 @@ CMainWindow::~CMainWindow()
     CActivityTrk::release();
 
     SETTINGS;
-    cfg.setValue("MainWindow/state", saveState());
-    cfg.setValue("MainWindow/geometry", saveGeometry());
-    cfg.setValue("MainWindow/units", IUnit::self().type);
+    cfg.beginGroup("MainWindow");
+    cfg.setValue("state", saveState());
+    cfg.setValue("geometry", saveGeometry());
+    cfg.setValue("units", IUnit::self().type);
     QStringList activeDockNames;
     for (QDockWidget * const & dock : activeDocks)
     {
         activeDockNames << dock->objectName();
     }
-    cfg.setValue("MainWindow/activedocks",activeDockNames);
+    cfg.setValue("activedocks",activeDockNames);
+
+    cfg.setValue("displaymode",static_cast<int>(displayMode));
+    cfg.setValue("dockstate",dockStates);
+    cfg.setValue("menuvisible",menuVisible);
+    cfg.endGroup();
 
     /*
        The "Canvas" section will hold all settings global to all views
@@ -402,6 +463,7 @@ CMainWindow::~CMainWindow()
     cfg.setValue("POIText", actionPOIText->isChecked());
     cfg.setValue("MapToolTip", actionMapToolTip->isChecked());
     cfg.setValue("isNight", actionNightDay->isChecked());
+    cfg.setValue("MinMaxTrackValues", actionMinMaxTrackValues->isChecked());
     cfg.setValue("flipMouseWheel", actionFlipMouseWheel->isChecked());
     cfg.setValue("profileIsWindow",actionProfileIsWindow->isChecked());
     cfg.setValue("mapFont", mapFont);
@@ -419,7 +481,7 @@ CMainWindow::~CMainWindow()
     /*
         Delete all canvas objects now to make sure they are destroyed before all
         other objects. This allows children of the canvas to access central objects
-        like CGisWidget safely upon their destruction. (e.g. CMouseRangeTrk to reset
+        like CGisWorkspace safely upon their destruction. (e.g. CMouseRangeTrk to reset
         it's track's draw mode by key)
      */
     qDeleteAll(allViews);
@@ -432,12 +494,22 @@ CMainWindow::~CMainWindow()
     cfg.setValue("Units/timezone", tz);
     cfg.setValue("Units/timezone/mode", tzmode);
     cfg.setValue("Units/time/useShortFormat", useShortFormat);
-
     cfg.setValue("Units/coordFormat", IUnit::getCoordFormat());
+    cfg.setValue("Units/slopeMode", IUnit::getSlopeMode());
 
     toolBarConfig->saveSettings();
 }
 
+CCanvas *CMainWindow::addView(const QString& name)
+{
+    CCanvas * view = new CCanvas(tabWidget, name);
+    tabWidget->addTab(view, view->objectName());
+    connect(view, &CCanvas::sigMousePosition, this, &CMainWindow::slotMousePosition);
+    connect(actionMinMaxTrackValues, &QAction::triggered, view, &CCanvas::slotUpdateTrackStatistic);
+
+    return view;
+}
+
 QWidget * CMainWindow::getBestWidgetForParent()
 {
     QWidget * w = CProgressDialog::self();
@@ -502,6 +574,11 @@ bool CMainWindow::isMapToolTip() const
     return actionMapToolTip->isChecked();
 }
 
+bool CMainWindow::isMinMaxTrackValues() const
+{
+    return actionMinMaxTrackValues->isChecked();
+}
+
 bool CMainWindow::flipMouseWheel() const
 {
     return actionFlipMouseWheel->isChecked();
@@ -538,6 +615,22 @@ CCanvas* CMainWindow::getVisibleCanvas() const
     return dynamic_cast<CCanvas*>(tabWidget->currentWidget());
 }
 
+QList<CCanvas*> CMainWindow::getCanvas() const
+{
+    QList<CCanvas*> result;
+    const int N = tabWidget->count();
+    for(int n = 0; n < N; n++)
+    {
+        CCanvas * canvas = dynamic_cast<CCanvas*>(tabWidget->widget(n));
+        if(canvas != nullptr)
+        {
+            result << canvas;
+        }
+    }
+
+    return result;
+}
+
 void CMainWindow::zoomCanvasTo(const QRectF rect)
 {
     CCanvas * canvas = getVisibleCanvas();
@@ -710,11 +803,8 @@ void CMainWindow::slotAddCanvas()
         }
     }
 
-    CCanvas * canvas = new CCanvas(tabWidget, QString());
-    tabWidget->addTab(canvas, canvas->objectName());
-    connect(canvas, &CCanvas::sigMousePosition, this, &CMainWindow::slotMousePosition);
-
-    tabWidget->setCurrentWidget(canvas);
+    CCanvas * view = addView(QString());
+    tabWidget->setCurrentWidget(view);
 
     testForNoView();
 }
@@ -894,7 +984,7 @@ void CMainWindow::slotMousePosition(const QPointF& pos, qreal ele, qreal slope)
     {
         QString val, unit;
         IUnit::self().meter2elevation(ele, val, unit);
-        lblElevation->setText(tr("Ele: %1%2").arg(val).arg(unit));
+        lblElevation->setText(tr("Ele.: %1%2").arg(val).arg(unit));
         lblElevation->show();
     }
     else
@@ -906,7 +996,7 @@ void CMainWindow::slotMousePosition(const QPointF& pos, qreal ele, qreal slope)
     {
         QString val;
         val.sprintf("%.1f", slope);
-        lblSlope->setText(tr("Slope: %1%2").arg(val).arg(QChar(0260)));
+        lblSlope->setText(tr("Slope: %1%2", "terrain").arg(val).arg("°"));
         lblSlope->show();
     }
     else
@@ -1082,7 +1172,7 @@ void CMainWindow::loadGISData(const QStringList& filenames)
 {
     for(const QString &filename : filenames)
     {
-        gisWidget->loadGisProject(filename);
+        widgetGisWorkspace->loadGisProject(filename);
     }
 }
 
@@ -1205,44 +1295,61 @@ void CMainWindow::slotCloseTab()
 
 void CMainWindow::slotToggleDocks()
 {
-    bool isHidden = true;
+    if (docksVisible())
+    {
+        dockStates = saveState();
+        hideDocks();
+    }
+    else
+    {
+        showDocks();
+        if (!dockStates.isEmpty())
+        {
+            restoreState(dockStates);
+        }
+    }
+}
+
+bool CMainWindow::docksVisible() const
+{
     for (QDockWidget * const & dock : docks)
     {
         if (!dock->isHidden())
         {
-            isHidden = false;
-            break;
+            return true;
         }
     }
+    return false;
+}
 
-    if (isHidden)
+void CMainWindow::showDocks() const
+{
+    if (activeDocks.isEmpty())
     {
-        if (activeDocks.isEmpty())
+        for (QDockWidget * const & dock : docks)
         {
-            for (QDockWidget * const & dock : docks)
-            {
-                dock->show();
-            }
-        }
-        else
-        {
-            const QList<QDockWidget *> docksToShow(activeDocks);
-            for (QDockWidget * const & dock : docksToShow)
-            {
-                dock->show();
-            }
+            dock->show();
         }
     }
     else
     {
-        activeDocks.clear();
-        for (QDockWidget * const & dock : docks)
+        const QList<QDockWidget *> docksToShow(activeDocks);
+        for (QDockWidget * const & dock : docksToShow)
         {
-            if (!dock->isHidden())
-            {
-                dock->hide();
-                activeDocks << dock;
-            }
+            dock->show();
+        }
+    }
+}
+
+void CMainWindow::hideDocks()
+{
+    activeDocks.clear();
+    for (QDockWidget * const & dock : docks)
+    {
+        if (!dock->isHidden())
+        {
+            dock->hide();
+            activeDocks << dock;
         }
     }
 }
@@ -1267,6 +1374,62 @@ void CMainWindow::slotDockVisibilityChanged(bool visible)
     actionToggleDocks->setChecked(visible);
 }
 
+void CMainWindow::slotFullScreen()
+{
+    QMutexLocker lock(&CMainWindow::mutex);
+
+    Qt::WindowStates state = windowState();
+    if(state == Qt::WindowFullScreen)
+    {
+        displayRegular();
+    }
+    else
+    {
+        displayMode = state;
+        displayFullscreen();
+    }
+}
+
+void CMainWindow::displayRegular()
+{
+    if (!dockStates.isEmpty())
+    {
+        restoreState(dockStates);
+    }
+    tabWidget->tabBar()->setVisible(true);
+    statusBar()->setVisible(true);
+    if (menuVisible)
+    {
+        menuBar()->setVisible(true);
+    }
+    actionFullScreen->setIcon(QIcon(":/icons/32x32/FullScreen.png"));
+    setWindowState(displayMode);
+}
+
+void CMainWindow::displayFullscreen()
+{
+    dockStates = saveState();
+    setWindowState(Qt::WindowFullScreen);
+    statusBar()->setVisible(false);
+    menuVisible = menuBar()->isVisible();
+    // menu is handled dynamically as on some platforms (e.g. ubuntu with unity)
+    // the menu is not visible but it's actions are active nevertheless
+    if (menuVisible)
+    {
+        menuBar()->setVisible(false);
+    }
+    if (docksVisible())
+    {
+        hideDocks();
+    }
+    if (!toolBarConfig->visibleInFullscreen())
+    {
+        toolBar->setVisible(false);
+    }
+    tabWidget->tabBar()->setVisible(false);
+    actionFullScreen->setIcon(QIcon(":/icons/32x32/RegularScreen.png"));
+}
+
 #ifdef WIN32
 
 static void sendDeviceEvent(DWORD unitmask, bool add)
@@ -1338,7 +1501,7 @@ void CMainWindow::dragEnterEvent(QDragEnterEvent *event)
         QFileInfo fi(urls[0].path());
         QString ext = fi.suffix().toUpper();
 
-        if ((ext == "QMS") || (ext == "GPX") || (ext == "SLF") || (ext == "FIT") || (ext == "TCX"))
+        if ((ext == "QMS") || (ext == "GPX") || (ext == "SLF") || (ext == "FIT") || (ext == "TCX") || (ext == "SML") || (ext == "LOG"))
         {
             event->acceptProposedAction();
         }
