@@ -26,7 +26,8 @@
 class CMapList;
 class CDemList;
 class QLabel;
-class CGisWidget;
+class CGisWorkspace;
+class CGisDatabase;
 class CCanvas;
 class CToolBarConfig;
 struct SGisLine;
@@ -55,6 +56,7 @@ public:
     bool isNight()         const;
     bool isPOIText()       const;
     bool isMapToolTip()    const;
+    bool isMinMaxTrackValues() const;
     bool flipMouseWheel()  const;
     bool profileIsWindow() const;
     const QFont& getMapFont() const
@@ -79,6 +81,7 @@ public:
        @return If the currently visible tab does not contain a CCanvas object 0 is returned.
      */
     CCanvas* getVisibleCanvas() const;
+    QList<CCanvas*> getCanvas() const;
 
     QAction * getMapSetupAction()
     {
@@ -138,12 +141,19 @@ private slots:
     void slotCloseTab();
     void slotToggleDocks();
     void slotDockVisibilityChanged(bool visible);
+    void slotFullScreen();
 
 private:
     friend int main(int argc, char ** argv);
     CMainWindow();
     void prepareMenuForMac();
     void testForNoView();
+    bool docksVisible() const;
+    void showDocks() const;
+    void hideDocks();
+    void displayRegular();
+    void displayFullscreen();
+    CCanvas * addView(const QString &name);
 
     static CMainWindow * pSelf;
 
@@ -155,12 +165,18 @@ private:
 
     QFont mapFont;
 
-    CGisWidget * gisWidget;
+    CGisWorkspace * widgetGisWorkspace;
+    CGisDatabase * widgetGisDatabase;
 
     CToolBarConfig * toolBarConfig;
 
     QList<QDockWidget *> docks;
     QList<QDockWidget *> activeDocks;
+    Qt::WindowStates displayMode = Qt::WindowMaximized;
+    QByteArray dockStates;
+    bool menuVisible = false;
+
+    static QMutex mutex;
 };
 
 #endif //CMAINWINDOW_H
