@@ -1,5 +1,6 @@
 /**********************************************************************************************
     Copyright (C) 2014 Oliver Eichler oliver.eichler@gmx.de
+    Copyright (C) 2017 Norbert Truchsess norbert.truchsess@t-online.de
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,7 +23,7 @@
 #include "canvas/CCanvasSetup.h"
 #include "dem/CDemDraw.h"
 #include "gis/CGisDraw.h"
-#include "gis/CGisWidget.h"
+#include "gis/CGisWorkspace.h"
 #include "gis/IGisLine.h"
 #include "gis/Poi.h"
 #include "gis/ovl/CGisItemOvlArea.h"
@@ -38,6 +39,7 @@
 #include "mouse/CMouseMoveWpt.h"
 #include "mouse/CMouseNormal.h"
 #include "mouse/CMousePrint.h"
+#include "mouse/CMouseRadiusWpt.h"
 #include "mouse/CMouseRangeTrk.h"
 #include "mouse/CMouseSelect.h"
 #include "mouse/CMouseWptBubble.h"
@@ -104,9 +106,13 @@ CCanvas::CCanvas(QWidget *parent, const QString &name)
     labelStatusMessages = new QLabel(this);
     labelStatusMessages->setWordWrap(true);
     labelStatusMessages->setMinimumWidth(300);
-    labelStatusMessages->setAlignment(Qt::AlignJustify);
     labelStatusMessages->hide();
 
+    labelTrackStatistic = new QLabel(this);
+    labelTrackStatistic->setWordWrap(true);
+    labelTrackStatistic->setMinimumWidth(300);
+    labelTrackStatistic->hide();
+
     connect(map, &CMapDraw::sigStartThread, mapLoadIndicator, &QLabel::show);
     connect(map, &CMapDraw::sigStopThread,  mapLoadIndicator, &QLabel::hide);
 
@@ -207,6 +213,11 @@ void CCanvas::resetMouse()
     }
 }
 
+void CCanvas::mouseTrackingLost()
+{
+    mouseLost = true;
+}
+
 void CCanvas::setMouseCursor(IMouse& mouse, const QString& src)
 {
     if(underMouse())
@@ -223,6 +234,13 @@ void CCanvas::setMouseMoveWpt(CGisItemWpt& wpt)
     setMouseCursor(*mouse, "setMouseMoveWpt");
 }
 
+void CCanvas::setMouseRadiusWpt(CGisItemWpt& wpt)
+{
+    mouse->deleteLater();
+    mouse = new CMouseRadiusWpt(wpt, gis, this);
+    setMouseCursor(*mouse, "setMouseWptRadius");
+}
+
 void CCanvas::setMouseEditTrk(const QPointF &pt)
 {
     mouse->deleteLater();
@@ -332,15 +350,18 @@ void CCanvas::resizeEvent(QResizeEvent * e)
     setDrawContextSize(e->size());
     QWidget::resizeEvent(e);
 
+    const QRect& r = rect();
+
     // move map loading indicator to new center of canvas
     QPoint p1(mapLoadIndicator->width()>>1, mapLoadIndicator->height()>>1);
-    mapLoadIndicator->move(rect().center() - p1);
+    mapLoadIndicator->move(r.center() - p1);
 
     QPoint p2(demLoadIndicator->width()>>1, demLoadIndicator->height()>>1);
-    demLoadIndicator->move(rect().center() - p2);
+    demLoadIndicator->move(r.center() - p2);
 
     labelStatusMessages->move(20,50);
 
+    slotUpdateTrackStatistic(CMainWindow::self().isMinMaxTrackValues());
     setSizeTrackProfile();
 }
 
@@ -381,6 +402,7 @@ void CCanvas::paintEvent(QPaintEvent*)
 
 
     drawStatusMessages(p);
+    drawTrackStatistic(p);
     drawScale(p);
 
     p.end();
@@ -433,7 +455,7 @@ void CCanvas::wheelEvent(QWheelEvent * e)
 
     // angleDelta() returns the eighths of a degree
     // of the mousewheel
-    // -> zoom in/out every 15 degress = every 120 eights
+    // -> zoom in/out every 15 degrees = every 120 eights
     const int EIGHTS_ZOOM = 15 * 8;
     zoomAngleDelta += e->angleDelta().y();
     if(abs(zoomAngleDelta) < EIGHTS_ZOOM)
@@ -544,9 +566,20 @@ void CCanvas::drawStatusMessages(QPainter& p)
 {
     if(labelStatusMessages->isVisible())
     {
-        QRect r = labelStatusMessages->rect();
+        QRect r = labelStatusMessages->frameGeometry();
+        r.adjust(-5, -5, 5, 5);
+        p.setPen(CDraw::penBorderGray);
+        p.setBrush(CDraw::brushBackWhite);
+        p.drawRoundedRect(r, RECT_RADIUS, RECT_RADIUS);
+    }
+}
+
+void CCanvas::drawTrackStatistic(QPainter& p)
+{
+    if(labelTrackStatistic->isVisible())
+    {
+        QRect r = labelTrackStatistic->frameGeometry();
         r.adjust(-5, -5, 5, 5);
-        r.moveTopLeft(QPoint(15,45));
         p.setPen(CDraw::penBorderGray);
         p.setBrush(CDraw::brushBackWhite);
         p.drawRoundedRect(r, RECT_RADIUS, RECT_RADIUS);
@@ -648,9 +681,11 @@ void CCanvas::slotCheckTrackOnFocus()
         delete plotTrackProfile;
         delete colorLegend;
         keyTrackOnFocus.clear();
+        labelTrackStatistic->clear();
+        labelTrackStatistic->hide();
 
         // get access to next track object
-        CGisItemTrk * trk2 = dynamic_cast<CGisItemTrk*>(CGisWidget::self().getItemByKey(key));
+        CGisItemTrk * trk2 = dynamic_cast<CGisItemTrk*>(CGisWorkspace::self().getItemByKey(key));
         if(nullptr == trk2)
         {
             return;
@@ -669,6 +704,32 @@ void CCanvas::slotCheckTrackOnFocus()
 
         // finally store the new key as track on focus
         keyTrackOnFocus = key;
+
+        slotUpdateTrackStatistic(CMainWindow::self().isMinMaxTrackValues());
+    }
+}
+
+void CCanvas::slotUpdateTrackStatistic(bool show)
+{
+    CGisItemTrk * trk = dynamic_cast<CGisItemTrk*>(CGisWorkspace::self().getItemByKey(keyTrackOnFocus));
+
+    if(show && trk)
+    {
+        QString text = trk->getInfo(IGisItem::eFeatureShowName|IGisItem::eFeatureShowActivity);
+        text += trk->getInfoLimits();
+
+        labelTrackStatistic->setMinimumWidth((trk->getActivities().getActivityCount() > 1) ? 450 : 350);
+        labelTrackStatistic->setText(text);
+        labelTrackStatistic->adjustSize();
+
+        labelTrackStatistic->move(rect().width() - labelTrackStatistic->width() - 20, rect().height() - labelTrackStatistic->height() - 60);
+        labelTrackStatistic->show();
+        update();
+    }
+    else
+    {
+        labelTrackStatistic->clear();
+        labelTrackStatistic->hide();
     }
 }
 
@@ -886,7 +947,7 @@ void CCanvas::showProfileAsWindow(bool yes)
         delete plotTrackProfile;
         keyTrackOnFocus.clear();
 
-        CGisWidget::self().focusTrkByKey(true, key);
+        CGisWorkspace::self().focusTrkByKey(true, key);
     }
 }
 
@@ -957,6 +1018,17 @@ bool CCanvas::event(QEvent *event)
     {
         return gestureEvent(static_cast<QGestureEvent*>(event));
     }
+    else if (mouseLost)
+    {
+        QMouseEvent * me = dynamic_cast<QMouseEvent*>(event);
+        if (me != nullptr)
+        {
+            // notify IMouse that the upcomming QMouseEvent needs special treatment
+            // as some mouse-events may have been lost
+            mouse->afterMouseLostEvent(me);
+            mouseLost = false;
+        }
+    }
     return QWidget::event(event);
 }
 
@@ -992,6 +1064,8 @@ bool CCanvas::gestureEvent(QGestureEvent* e)
                 slotTriggerCompleteUpdate(needsRedraw);
             }
         }
+        mouseLost = true;
+        mouse->pinchGestureEvent(pinch);
     }
     return true;
 }
