@@ -1,5 +1,6 @@
 /**********************************************************************************************
     Copyright (C) 2014 Oliver Eichler oliver.eichler@gmx.de
+    Copyright (C) 2017 Norbert Truchsess norbert.truchsess@t-online.de
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -108,7 +109,9 @@ public:
 
 
     void resetMouse();
+    void mouseTrackingLost();
     void setMouseMoveWpt(CGisItemWpt& wpt);
+    void setMouseRadiusWpt(CGisItemWpt& wpt);
     void setMouseEditTrk(CGisItemTrk& trk);
     void setMouseRangeTrk(CGisItemTrk& trk);
     void setMouseEditTrk(const QPointF& pt);
@@ -160,6 +163,7 @@ signals:
 
 public slots:
     void slotTriggerCompleteUpdate(CCanvas::redraw_e flags);
+    void slotUpdateTrackStatistic(bool show);
 
 protected:
     bool event(QEvent *) override;
@@ -180,8 +184,10 @@ private slots:
     void slotToolTip();
     void slotCheckTrackOnFocus();
 
+
 private:
     void drawStatusMessages(QPainter& p);
+    void drawTrackStatistic(QPainter& p);
     void drawScale(QPainter& p);
     void setZoom(bool in, redraw_e &needsRedraw);
     void setSizeTrackProfile();
@@ -189,6 +195,7 @@ private:
     void setDrawContextSize(const QSize& s);
     void setMouseCursor(IMouse& mouse, const QString& src);
 
+
     QColor backColor = "#FFFFBF";       //< the background color used in case of missing map tiles
     redraw_e needsRedraw = eRedrawAll;  //< set true to initiate a complete redraw of the screen content
     CMapDraw * map;                     //< the map object attached to this canvas
@@ -226,11 +233,14 @@ private:
     IGisItem::key_t keyTrackOnFocus;
     /// the track profile plot
     QPointer<IPlot>  plotTrackProfile;
+    /// a label with a track
+    QLabel * labelTrackStatistic;
 
     QLabel * labelStatusMessages;
     QMap<QString, QString> statusMessages;
 
     QMutex mousePressMutex;
+    bool mouseLost = false;
 };
 
 #endif //CCANVAS_H
