@@ -123,6 +123,11 @@ public:
         return scalesType;
     }
 
+    const QPointF& getZoomFactor() const
+    {
+        return zoomFactor;
+    }
+
     /**
        @brief Set the projection of the draw context
 
@@ -139,6 +144,7 @@ public:
 
     virtual void setScales(const CCanvas::scales_type_e type);
 
+
 signals:
     void sigCanvasUpdate(CCanvas::redraw_e flags);
     void sigStartThread();
