@@ -36,8 +36,8 @@ signals:
     void sigChanged();
 
 protected:
-    void dragMoveEvent ( QDragMoveEvent  * event );
-    void dropEvent ( QDropEvent  * event );
+    void dragMoveEvent(QDragMoveEvent *event) override;
+    void dropEvent(QDropEvent     *event) override;
 };
 
 
@@ -62,10 +62,15 @@ public:
 
 signals:
     void sigChanged();
+    void sigSetupDemPath();
 
 private slots:
     void slotActivate();
+    void slotMoveUp();
+    void slotMoveDown();
+    void slotReloadDem();
     void slotContextMenu(const QPoint &point);
+    void slotLinkActivated(const QString& link);
 
 private:
     QMenu * menu;
