@@ -1,5 +1,6 @@
 /**********************************************************************************************
     Copyright (C) 2014 Oliver Eichler oliver.eichler@gmx.de
+    Copyright (C) 2017 Norbert Truchsess norbert.truchsess@t-online.de
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -28,8 +29,9 @@
 #include "device/CDeviceWatcherMac.h"
 #endif
 #include "device/IDevice.h"
+#include "gis/CGisDatabase.h"
 #include "gis/CGisListWks.h"
-#include "gis/CGisWidget.h"
+#include "gis/CGisWorkspace.h"
 #include "gis/CSelDevices.h"
 #include "gis/IGisItem.h"
 #include "gis/db/CDBProject.h"
@@ -41,10 +43,13 @@
 #include "gis/gpx/CGpxProject.h"
 #include "gis/ovl/CGisItemOvlArea.h"
 #include "gis/prj/IGisProject.h"
+#include "gis/qlb/CQlbProject.h"
 #include "gis/qms/CQmsProject.h"
 #include "gis/rte/CGisItemRte.h"
 #include "gis/search/CSearchGoogle.h"
 #include "gis/slf/CSlfProject.h"
+#include "gis/suunto/CLogProject.h"
+#include "gis/suunto/CSmlProject.h"
 #include "gis/tcx/CTcxProject.h"
 #include "gis/trk/CGisItemTrk.h"
 #include "gis/wpt/CGisItemWpt.h"
@@ -103,17 +108,20 @@ CGisListWks::CGisListWks(QWidget *parent)
     actionShowOnMap  = menuProjectWks->addAction(QIcon("://icons/32x32/ShowAll.png"    ), tr("Show on Map"    ), this, SLOT(slotShowOnMap()));
     actionHideFrMap  = menuProjectWks->addAction(QIcon("://icons/32x32/ShowNone.png"   ), tr("Hide from Map"  ), this, SLOT(slotHideFrMap()));
 
-
     menuProjectWks->addSeparator();
     actionGroup = new QActionGroup(menuProjectWks);
     actionGroup->setExclusive(true);
     actionSortByTime = addSortAction(menuProjectWks, actionGroup, "://icons/32x32/Time.png", tr("Sort by Time"), IGisProject::eSortFolderTime);
     actionSortByName = addSortAction(menuProjectWks, actionGroup, "://icons/32x32/SortName.png", tr("Sort by Name"), IGisProject::eSortFolderName);
 
+    menuProjectWks->addSeparator();
+    actionAutoSave   = menuProjectWks->addAction(QIcon("://icons/32x32/AutoSave.png"), tr("Autom. Save"));
+    actionAutoSave->setCheckable(true);
+
     menuProjectWks->addSeparator();
     actionSave       = menuProjectWks->addAction(QIcon("://icons/32x32/SaveGIS.png"    ), tr("Save"           ), this, SLOT(slotSaveProject()));
     actionSaveAs     = menuProjectWks->addAction(QIcon("://icons/32x32/SaveGISAs.png"  ), tr("Save as..."     ), this, SLOT(slotSaveAsProject()));
-    actionSaveAsStrict = menuProjectWks->addAction(QIcon("://icons/32x32/SaveGISAsGpx11.png"  ), tr("Save as GPX 1.1 w/o ext..."), this, SLOT(slotSaveAsStrictGpx11Project()));
+    actionSaveAsStrict = menuProjectWks->addAction(QIcon("://icons/32x32/SaveGISAsGpx11.png"), tr("Save as GPX 1.1 w/o ext..."), this, SLOT(slotSaveAsStrictGpx11Project()));
 
     menuProjectWks->addSeparator();
     actionSyncWksDev = menuProjectWks->addAction(QIcon("://icons/32x32/Device.png"     ), tr("Send to Devices"), this, SLOT(slotSyncWksDev()));
@@ -152,9 +160,11 @@ CGisListWks::CGisListWks(QWidget *parent)
     actionEditTrk    = menuItemTrk->addAction(QIcon("://icons/32x32/LineMove.png"),    tr("Edit Track Points"      ), this, SLOT(slotEditTrk()));
     actionReverseTrk = menuItemTrk->addAction(QIcon("://icons/32x32/Reverse.png"),     tr("Reverse Track"          ), this, SLOT(slotReverseTrk()));
     actionCombineTrk = menuItemTrk->addAction(QIcon("://icons/32x32/Combine.png"),     tr("Combine Tracks"         ), this, SLOT(slotCombineTrk()));
+    actionActivityTrk= menuItemTrk->addAction(QIcon("://icons/32x32/Activity.png"), tr("Set Track Activity"), this, SLOT(slotActivityTrk()));
     actionCopyTrkWithWpt = menuItemTrk->addAction(QIcon("://icons/32x32/CopyTrkWithWpt.png"), tr("Copy Track with Waypoints"), this, SLOT(slotCopyTrkWithWpt()));
     menuItemTrk->addSeparator();
     actionDelete    = menuItemTrk->addAction(QIcon("://icons/32x32/DeleteOne.png"),tr("Delete"), this, SLOT(slotDeleteItem()));
+    connect(menuItemTrk, &QMenu::triggered, &CGisWorkspace::self(), &CGisWorkspace::slotWksItemSelectionReset);
 
     menuItemWpt     = new QMenu(this);
     menuItemWpt->addAction(actionEditDetails);
@@ -164,8 +174,13 @@ CGisListWks::CGisListWks(QWidget *parent)
     actionBubbleWpt->setCheckable(true);
     actionMoveWpt   = menuItemWpt->addAction(QIcon("://icons/32x32/WptMove.png"), tr("Move Waypoint"),     this, SLOT(slotMoveWpt()));
     actionProjWpt   = menuItemWpt->addAction(QIcon("://icons/32x32/WptProj.png"), tr("Proj. Waypoint..."), this, SLOT(slotProjWpt()));
+    actionEditRadiusWpt = menuItemWpt->addAction(QIcon("://icons/32x32/WptEditProx.png"), tr("Change Radius"), this, SLOT(slotEditRadiusWpt()));
+    actionNogoAreaWpt = menuItemWpt->addAction(QIcon("://icons/32x32/WptAvoid.png"), tr("Toggle Nogo-Area"), this, SLOT(slotNogoAreaWpt()));
+    actionNogoAreaWpt->setCheckable(true);
+    actionDelRadiusWpt = menuItemWpt->addAction(QIcon("://icons/32x32/WptDelProx.png"), tr("Delete Radius"), this, SLOT(slotDelRadiusWpt()));
     menuItemWpt->addSeparator();
     menuItemWpt->addAction(actionDelete);
+    connect(menuItemWpt, &QMenu::triggered, &CGisWorkspace::self(), &CGisWorkspace::slotWksItemSelectionReset);
 
     menuItemRte     = new QMenu(this);
     menuItemRte->addAction(actionEditDetails);
@@ -179,6 +194,7 @@ CGisListWks::CGisListWks(QWidget *parent)
     actionRte2Trk   = menuItemRte->addAction(QIcon("://icons/32x32/Track.png"),    tr("Convert to Track"),this, SLOT(slotRte2Trk()));
     menuItemRte->addSeparator();
     menuItemRte->addAction(actionDelete);
+    connect(menuItemRte, &QMenu::triggered, &CGisWorkspace::self(), &CGisWorkspace::slotWksItemSelectionReset);
 
 
     menuItemOvl     = new QMenu(this);
@@ -188,6 +204,7 @@ CGisListWks::CGisListWks(QWidget *parent)
     actionEditArea  = menuItemOvl->addAction(QIcon("://icons/32x32/AreaMove.png"),tr("Edit Area Points"), this, SLOT(slotEditArea()));
     menuItemOvl->addSeparator();
     menuItemOvl->addAction(actionDelete);
+    connect(menuItemOvl, &QMenu::triggered, &CGisWorkspace::self(), &CGisWorkspace::slotWksItemSelectionReset);
 
 
     menuItem        = new QMenu(this);
@@ -195,12 +212,14 @@ CGisListWks::CGisListWks(QWidget *parent)
     actionRteFromWpt = menuItem->addAction(QIcon("://icons/32x32/Route.png"), tr("Create Route"), this, SLOT(slotRteFromWpt()));
     actionSymWpt    = menuItem->addAction(QIcon("://icons/waypoints/32x32/PinBlue.png"), tr("Change Icon (sel. waypt. only)"), this, SLOT(slotSymWpt()));
     menuItem->addAction(actionCombineTrk);
+    menuItem->addAction(actionActivityTrk);
     menuItem->addAction(actionDelete);
+    connect(menuItem, &QMenu::triggered, &CGisWorkspace::self(), &CGisWorkspace::slotWksItemSelectionReset);
 
-
-    connect(actionFocusTrk, &QAction::triggered,        this, &CGisListWks::slotFocusTrk);
-    connect(actionFocusRte, &QAction::triggered,        this, &CGisListWks::slotFocusRte);
-    connect(qApp,           &QApplication::aboutToQuit, this, &CGisListWks::slotSaveWorkspace);
+    connect(actionFocusTrk, &QAction::triggered, this, &CGisListWks::slotFocusTrk);
+    connect(actionFocusRte, &QAction::triggered, this, &CGisListWks::slotFocusRte);
+    connect(actionAutoSave, &QAction::triggered, this, &CGisListWks::slotAutoSaveProject);
+    connect(qApp, &QApplication::aboutToQuit, this, &CGisListWks::slotSaveWorkspace);
 
     SETTINGS;
     saveOnExit  = cfg.value("Database/saveOnExit", saveOnExit).toBool();
@@ -849,6 +868,14 @@ void CGisListWks::slotLoadWorkspace()
             break;
         }
 
+        case IGisProject::eTypeQlb:
+        {
+            project = new CQlbProject(name, this);
+            project->setCheckState(CGisListDB::eColumnCheckbox, visible); // (1a)
+            *project << stream;
+            break;
+        }
+
         case IGisProject::eTypeGpx:
         {
             project = new CGpxProject(name, this);
@@ -905,6 +932,22 @@ void CGisListWks::slotLoadWorkspace()
             *project << stream;
             break;
         }
+
+        case IGisProject::eTypeSml:
+        {
+            project = new CSmlProject(name, this);
+            project->setCheckState(CGisListDB::eColumnCheckbox, visible);
+            *project << stream;
+            break;
+        }
+
+        case IGisProject::eTypeLog:
+        {
+            project = new CSmlProject(name, this);
+            project->setCheckState(CGisListDB::eColumnCheckbox, visible);
+            *project << stream;
+            break;
+        }
         }
 
         if(nullptr != project)
@@ -980,6 +1023,7 @@ void CGisListWks::slotContextMenu(const QPoint& point)
                 actionGroup->setEnabled(false);
                 actionSyncWksDev->setEnabled(IDevice::count());
                 actionSyncDB->setEnabled(project->getType() == IGisProject::eTypeDb);
+                actionAutoSave->setVisible(false);
                 menuProjectWks->exec(p);
             }
             return;
@@ -1015,6 +1059,7 @@ void CGisListWks::slotContextMenu(const QPoint& point)
 
             actionRteFromWpt->setEnabled(onlyWpts);
             actionCombineTrk->setEnabled(onlyTrks);
+            actionActivityTrk->setEnabled(onlyTrks);
             actionSymWpt->setEnabled(hasWpts);
 
             menuItem->exec(p);
@@ -1058,6 +1103,10 @@ void CGisListWks::slotContextMenu(const QPoint& point)
 
                     blockSorting = false;
 
+                    actionAutoSave->setVisible(true);
+                    actionAutoSave->setEnabled(project->canSave());
+                    actionAutoSave->setChecked(project->isAutoSave());
+
                     menuProjectWks->exec(p);
                 }
             }
@@ -1093,11 +1142,18 @@ void CGisListWks::slotContextMenu(const QPoint& point)
             }
 
             case IGisItem::eTypeWpt:
-                actionBubbleWpt->setChecked(dynamic_cast<CGisItemWpt*>(gisItem)->hasBubble());
+            {
+                CGisItemWpt * wpt = dynamic_cast<CGisItemWpt*>(gisItem);
+                actionBubbleWpt->setChecked(wpt->hasBubble());
+                bool radius = wpt->hasRadius();
+                actionDelRadiusWpt->setEnabled(radius);
+                actionNogoAreaWpt->setEnabled(radius);
+                actionNogoAreaWpt->setChecked(radius && wpt->isNogoArea());
                 actionMoveWpt->setDisabled(isOnDevice);
                 actionProjWpt->setDisabled(isOnDevice);
                 menuItemWpt->exec(p);
                 break;
+            }
 
             case IGisItem::eTypeRte:
                 actionFocusRte->setChecked(gisItem->hasUserFocus());
@@ -1179,6 +1235,9 @@ void CGisListWks::slotCloseAllProjects()
 
     CGisListWksEditLock lock(true, IGisItem::mutexItems);
     closeProjects(findItems("*", Qt::MatchWildcard));
+
+    CGisWorkspace::self().slotWksItemSelectionReset();
+
     emit sigChanged();
 }
 
@@ -1263,6 +1322,17 @@ void CGisListWks::slotSaveAsStrictGpx11Project()
     }
 }
 
+void CGisListWks::slotAutoSaveProject(bool on)
+{
+    CGisListWksEditLock lock(false, IGisItem::mutexItems);
+
+    IGisProject * project = dynamic_cast<IGisProject*>(currentItem());
+    if(project != nullptr)
+    {
+        project->setAutoSave(on);
+    }
+}
+
 void CGisListWks::slotEditPrj()
 {
     CGisListWksEditLock lock(false, IGisItem::mutexItems);
@@ -1281,8 +1351,9 @@ void CGisListWks::slotItemDoubleClicked(QTreeWidgetItem * item, int )
     IGisItem * gisItem = dynamic_cast<IGisItem*>(item);
     if(gisItem != nullptr)
     {
+        CGisWorkspace::self().slotWksItemSelectionReset();
         CMainWindow::self().zoomCanvasTo(gisItem->getBoundingRect());
-        CGisWidget::self().focusTrkByKey(true, gisItem->getKey());
+        CGisWorkspace::self().focusTrkByKey(true, gisItem->getKey());
     }
 }
 
@@ -1290,7 +1361,7 @@ void CGisListWks::slotItemChanged(QTreeWidgetItem * item, int column)
 {
     CGisListWksEditLock lock(true, IGisItem::mutexItems);
 
-    if(column == CGisListDB::eColumnCheckbox)
+    if(column == eColumnCheckBox)
     {
         emit sigChanged();
     }
@@ -1303,7 +1374,7 @@ void CGisListWks::slotEditItem()
     IGisItem * gisItem = dynamic_cast<IGisItem*>(currentItem());
     if(gisItem != nullptr)
     {
-        CGisWidget::self().editItemByKey(gisItem->getKey());
+        CGisWorkspace::self().editItemByKey(gisItem->getKey());
     }
 }
 
@@ -1322,7 +1393,7 @@ void CGisListWks::slotDeleteItem()
         }
     }
 
-    CGisWidget::self().delItemsByKey(keys);
+    CGisWorkspace::self().delItemsByKey(keys);
 }
 
 void CGisListWks::slotCopyItem()
@@ -1335,7 +1406,7 @@ void CGisListWks::slotCopyItem()
      * to get invalid, causing a segfault when used.
      *
      * As a fix the keys of the selected items are stored temporarily and
-     * later used to retrieve the item on the workspace via CGisWidget::getItemByKey()
+     * later used to retrieve the item on the workspace via CGisWorkspace::getItemByKey()
      * again. This is always safe.
      */
     QList<QTreeWidgetItem*> items = selectedItems();
@@ -1349,7 +1420,7 @@ void CGisListWks::slotCopyItem()
         }
     }
 
-    CGisWidget::self().copyItemsByKey(keys);
+    CGisWorkspace::self().copyItemsByKey(keys);
 }
 
 void CGisListWks::slotProjWpt()
@@ -1359,7 +1430,7 @@ void CGisListWks::slotProjWpt()
     CGisItemWpt * gisItem = dynamic_cast<CGisItemWpt*>(currentItem());
     if(gisItem != nullptr)
     {
-        CGisWidget::self().projWptByKey(gisItem->getKey());
+        CGisWorkspace::self().projWptByKey(gisItem->getKey());
     }
 }
 
@@ -1370,7 +1441,40 @@ void CGisListWks::slotBubbleWpt()
     CGisItemWpt * gisItem = dynamic_cast<CGisItemWpt*>(currentItem());
     if(gisItem != nullptr)
     {
-        CGisWidget::self().toggleWptBubble(gisItem->getKey());
+        CGisWorkspace::self().toggleWptBubble(gisItem->getKey());
+    }
+}
+
+void CGisListWks::slotNogoAreaWpt()
+{
+    CGisListWksEditLock lock(false, IGisItem::mutexItems);
+
+    CGisItemWpt * gisItem = dynamic_cast<CGisItemWpt*>(currentItem());
+    if(gisItem != nullptr)
+    {
+        CGisWorkspace::self().toggleWptNogoArea(gisItem->getKey());
+    }
+}
+
+void CGisListWks::slotDelRadiusWpt()
+{
+    CGisListWksEditLock lock(false, IGisItem::mutexItems);
+
+    CGisItemWpt * gisItem = dynamic_cast<CGisItemWpt*>(currentItem());
+    if(gisItem != nullptr)
+    {
+        CGisWorkspace::self().deleteWptRadius(gisItem->getKey());
+    }
+}
+
+void CGisListWks::slotEditRadiusWpt()
+{
+    CGisListWksEditLock lock(false, IGisItem::mutexItems);
+
+    CGisItemWpt * gisItem = dynamic_cast<CGisItemWpt*>(currentItem());
+    if(gisItem != nullptr)
+    {
+        CGisWorkspace::self().editWptRadius(gisItem->getKey());
     }
 }
 
@@ -1381,7 +1485,7 @@ void CGisListWks::slotMoveWpt()
     CGisItemWpt * gisItem = dynamic_cast<CGisItemWpt*>(currentItem());
     if(gisItem != nullptr)
     {
-        CGisWidget::self().moveWptByKey(gisItem->getKey());
+        CGisWorkspace::self().moveWptByKey(gisItem->getKey());
     }
 }
 
@@ -1392,7 +1496,7 @@ void CGisListWks::slotFocusTrk(bool on)
     CGisItemTrk * gisItem = dynamic_cast<CGisItemTrk*>(currentItem());
     if(gisItem != nullptr)
     {
-        CGisWidget::self().focusTrkByKey(on, gisItem->getKey());
+        CGisWorkspace::self().focusTrkByKey(on, gisItem->getKey());
     }
 }
 
@@ -1403,7 +1507,7 @@ void CGisListWks::slotEditTrk()
     CGisItemTrk * gisItem = dynamic_cast<CGisItemTrk*>(currentItem());
     if(gisItem != nullptr)
     {
-        CGisWidget::self().editTrkByKey(gisItem->getKey());
+        CGisWorkspace::self().editTrkByKey(gisItem->getKey());
     }
 }
 
@@ -1414,7 +1518,7 @@ void CGisListWks::slotReverseTrk()
     CGisItemTrk * gisItem = dynamic_cast<CGisItemTrk*>(currentItem());
     if(gisItem != nullptr)
     {
-        CGisWidget::self().reverseTrkByKey(gisItem->getKey());
+        CGisWorkspace::self().reverseTrkByKey(gisItem->getKey());
     }
 }
 
@@ -1437,11 +1541,29 @@ void CGisListWks::slotCombineTrk()
     {
         if(keys.size() == 1)
         {
-            CGisWidget::self().combineTrkByKey(keys.first());
+            CGisWorkspace::self().combineTrkByKey(keys.first());
         }
         else
         {
-            CGisWidget::self().combineTrkByKey(keys, keys);
+            CGisWorkspace::self().combineTrkByKey(keys, keys);
+        }
+    }
+}
+
+void CGisListWks::slotActivityTrk()
+{
+    quint32 flags = CActivityTrk::selectActivity(this);
+    if(0xFFFFFFFF != flags)
+    {
+        CGisListWksEditLock lock(true, IGisItem::mutexItems);
+        QList<QTreeWidgetItem*> items = selectedItems();
+        for(QTreeWidgetItem * item : items)
+        {
+            CGisItemTrk * trk = dynamic_cast<CGisItemTrk*>(item);
+            if(trk)
+            {
+                trk->setActivity(flags);
+            }
         }
     }
 }
@@ -1453,7 +1575,7 @@ void CGisListWks::slotRangeTrk()
     CGisItemTrk * gisItem = dynamic_cast<CGisItemTrk*>(currentItem());
     if(gisItem != nullptr)
     {
-        CGisWidget::self().rangeTrkByKey(gisItem->getKey());
+        CGisWorkspace::self().rangeTrkByKey(gisItem->getKey());
     }
 }
 
@@ -1464,7 +1586,7 @@ void CGisListWks::slotCopyTrkWithWpt()
     CGisItemTrk * gisItem = dynamic_cast<CGisItemTrk*>(currentItem());
     if(gisItem != nullptr)
     {
-        CGisWidget::self().copyTrkWithWptByKey(gisItem->getKey());
+        CGisWorkspace::self().copyTrkWithWptByKey(gisItem->getKey());
     }
 }
 
@@ -1475,7 +1597,7 @@ void CGisListWks::slotFocusRte(bool on)
     CGisItemRte * gisItem = dynamic_cast<CGisItemRte*>(currentItem());
     if(gisItem != nullptr)
     {
-        CGisWidget::self().focusRteByKey(on, gisItem->getKey());
+        CGisWorkspace::self().focusRteByKey(on, gisItem->getKey());
     }
 }
 
@@ -1486,7 +1608,7 @@ void CGisListWks::slotCalcRte()
     CGisItemRte * gisItem = dynamic_cast<CGisItemRte*>(currentItem());
     if(gisItem != nullptr)
     {
-        CGisWidget::self().calcRteByKey(gisItem->getKey());
+        CGisWorkspace::self().calcRteByKey(gisItem->getKey());
     }
 }
 
@@ -1497,7 +1619,7 @@ void CGisListWks::slotResetRte()
     CGisItemRte * gisItem = dynamic_cast<CGisItemRte*>(currentItem());
     if(gisItem != nullptr)
     {
-        CGisWidget::self().resetRteByKey(gisItem->getKey());
+        CGisWorkspace::self().resetRteByKey(gisItem->getKey());
     }
 }
 
@@ -1509,7 +1631,7 @@ void CGisListWks::slotEditRte()
     CGisItemRte * gisItem = dynamic_cast<CGisItemRte*>(currentItem());
     if(gisItem != nullptr)
     {
-        CGisWidget::self().editRteByKey(gisItem->getKey());
+        CGisWorkspace::self().editRteByKey(gisItem->getKey());
     }
 }
 
@@ -1520,7 +1642,7 @@ void CGisListWks::slotRte2Trk()
     CGisItemRte * gisItem = dynamic_cast<CGisItemRte*>(currentItem());
     if(gisItem != nullptr)
     {
-        CGisWidget::self().convertRouteToTrack(gisItem->getKey());
+        CGisWorkspace::self().convertRouteToTrack(gisItem->getKey());
     }
 }
 
@@ -1531,7 +1653,7 @@ void CGisListWks::slotEditArea()
     CGisItemOvlArea * gisItem = dynamic_cast<CGisItemOvlArea*>(currentItem());
     if(gisItem != nullptr)
     {
-        CGisWidget::self().editAreaByKey(gisItem->getKey());
+        CGisWorkspace::self().editAreaByKey(gisItem->getKey());
     }
 }
 
@@ -1543,7 +1665,10 @@ void CGisListWks::slotAddEmptyProject()
     QString key, name;
     IGisProject::type_e type;
     CSelectProjectDialog dlg(key, name, type, nullptr);
-    dlg.exec();
+    if(dlg.exec() == QDialog::Rejected)
+    {
+        return;
+    }
     if(name.isEmpty() && (type != IGisProject::eTypeDb))
     {
         return;
@@ -1577,7 +1702,7 @@ void CGisListWks::slotAddEmptyProject()
         }
 
         CEvtW2DCreate * evt = new CEvtW2DCreate(name, type, idParent, db, host);
-        CGisWidget::self().postEventForDb(evt);
+        CGisDatabase::self().postEventForDb(evt);
     }
 }
 
@@ -1760,6 +1885,7 @@ bool CGisListWks::event(QEvent * e)
 
             e->accept();
             emit sigChanged();
+            emit sigItemDeleted();
             return true;
         }
 
@@ -1786,6 +1912,7 @@ bool CGisListWks::event(QEvent * e)
             }
             e->accept();
             emit sigChanged();
+            emit sigItemDeleted();
             return true;
         }
 
@@ -1843,7 +1970,21 @@ bool CGisListWks::event(QEvent * e)
         case eEvtA2WCutTrk:
         {
             CEvtA2WCutTrk * evt = (CEvtA2WCutTrk*)e;
-            CGisWidget::self().cutTrkByKey(evt->key);
+            CGisWorkspace::self().cutTrkByKey(evt->key);
+            e->accept();
+            return true;
+        }
+
+        case eEvtA2WSave:
+        {
+            CEvtA2WSave * evt = (CEvtA2WSave*)e;
+
+            IGisProject * project = getProjectByKey(evt->key);
+            if(project)
+            {
+                project->save();
+                project->confirmPendingAutoSave();
+            }
             e->accept();
             return true;
         }
@@ -1870,7 +2011,7 @@ void CGisListWks::slotRteFromWpt()
 
     if(!keys.isEmpty())
     {
-        CGisWidget::self().makeRteFromWpt(keys);
+        CGisWorkspace::self().makeRteFromWpt(keys);
     }
 }
 
@@ -1931,7 +2072,7 @@ void CGisListWks::slotCopyProject()
         }
     }
 
-    CGisWidget::self().copyItemsByKey(keys);
+    CGisWorkspace::self().copyItemsByKey(keys);
 }
 
 
@@ -1957,5 +2098,5 @@ void CGisListWks::slotSymWpt()
         keys << wpt->getKey();
     }
 
-    CGisWidget::self().changeWptSymByKey(keys, tb.objectName());
+    CGisWorkspace::self().changeWptSymByKey(keys, tb.objectName());
 }
