@@ -22,7 +22,7 @@
 #include "device/IDevice.h"
 #include "gis/CGisDraw.h"
 #include "gis/CGisListWks.h"
-#include "gis/CGisWidget.h"
+#include "gis/CGisWorkspace.h"
 #include "gis/IGisItem.h"
 #include "gis/db/macros.h"
 #include "gis/ovl/CGisItemOvlArea.h"
@@ -31,6 +31,7 @@
 #include "gis/trk/CGisItemTrk.h"
 #include "gis/wpt/CGisItemWpt.h"
 #include "helpers/CDraw.h"
+#include "helpers/CSettings.h"
 #include "units/IUnit.h"
 
 #include <QtSql>
@@ -283,7 +284,7 @@ QString IGisItem::getNameEx() const
 void IGisItem::updateDecoration(quint32 enable, quint32 disable)
 {
     // update text and icon
-    setToolTip(CGisListWks::eColumnName,getInfo(true, false));
+    setToolTip(CGisListWks::eColumnName,getInfo(IGisItem::eFeatureShowName));
     setText(CGisListWks::eColumnName, getName());
     setSymbol();
 
@@ -523,16 +524,28 @@ bool IGisItem::setReadOnlyMode(bool readOnly)
     // warn if item is external and read only
     if(!(flags & (eFlagCreatedInQms|eFlagTainted)))
     {
-        if(isReadOnly() && !readOnly)
+        SETTINGS;
+        bool doNotAsk = cfg.value("Dialog/Items/ReadOnly/doNotAsk", false).toBool();
+
+        if(isReadOnly() && !readOnly && !doNotAsk)
         {
             CCanvas::setOverrideCursor(Qt::ArrowCursor, "setReadOnlyMode");
-            QString str = tr("<h3>%1</h3> This element is probably read-only because it was not created within QMapShack. Usually you should not want to change imported data. But if you think that is ok press 'Ok'.").arg(getName());
-            int res = QMessageBox::warning(CMainWindow::getBestWidgetForParent(), tr("Read Only Mode..."), str, QMessageBox::Ok|QMessageBox::Abort, QMessageBox::Ok);
+
+            QCheckBox * checkBox = new QCheckBox(tr("Never ask again."), 0);
+            QString msg = tr("<h3>%1</h3> This element is probably read-only because it was not created within QMapShack. Usually you should not want to change imported data. But if you think that is ok press 'Ok'.").arg(getName());
+            QMessageBox box(QMessageBox::Warning, tr("Read Only Mode..."), msg, QMessageBox::Ok|QMessageBox::Abort, CMainWindow::getBestWidgetForParent());
+            box.setDefaultButton(QMessageBox::Ok);
+            box.setCheckBox(checkBox);
+            int res = box.exec();
+
             CCanvas::restoreOverrideCursor("setReadOnlyMode");
+
             if(res != QMessageBox::Ok)
             {
                 return false;
             }
+
+            cfg.setValue("Dialog/Items/ReadOnly/doNotAsk", checkBox->isChecked());
         }
     }
 
@@ -794,7 +807,7 @@ bool IGisItem::isVisible(const QRectF &rect, const QPolygonF& viewport, CGisDraw
     QPolygonF tmp2 = viewport;
     gis->convertRad2Px(tmp2);
 
-    return tmp2.boundingRect().intersects(tmp2.boundingRect());
+    return tmp2.boundingRect().intersects(tmp1.boundingRect());
 }
 
 bool IGisItem::isVisible(const QPointF& point, const QPolygonF& viewport, CGisDraw * gis)
@@ -815,6 +828,11 @@ bool IGisItem::isChanged() const
 
 bool IGisItem::isWithin(const QRectF& area, selflags_t flags, const QPolygonF& points)
 {
+    if(points.isEmpty())
+    {
+        return false;
+    }
+
     if(flags & eSelectionExact)
     {
         for(const QPointF &point : points)
@@ -849,7 +867,7 @@ bool IGisItem::getNameAndProject(QString &name, IGisProject *&project, const QSt
         return false;
     }
 
-    project = CGisWidget::self().selectProject();
+    project = CGisWorkspace::self().selectProject();
     return nullptr != project;
 }
 
