@@ -248,15 +248,24 @@ public:
      */
     virtual QString getNameEx() const;
 
+
+    enum features_e
+    {
+        eFeatureNone            = 0
+        , eFeatureShowName      = 0x00000001
+        , eFeatureShowFullText  = 0x00000002
+        , eFeatureShowActivity  = 0x00000004
+    };
+
     /**
        @brief Get a short string with the items properties to be displayed in tool tips or similar
 
        @param showName          set true if the first line should be the item's name
-       @apram showFullText      set false to get a 200 characters limited info text
+       @param features          a combination of features_e types
 
        @return A string object.
      */
-    virtual QString getInfo(bool showName, bool showFullText) const = 0;
+    virtual QString getInfo(quint32 features) const = 0;
 
     virtual const QString& getComment() const = 0;
     virtual const QString& getDescription() const = 0;
@@ -471,7 +480,7 @@ public:
        @param desc          the description string
        @param links         a list of links
        @param key           some key to be sent with the header links
-       @return The formated text ready to be used.
+       @return The formatted text ready to be used.
      */
     static QString createText(bool isReadOnly, const QString& cmt, const QString& desc, const QList<link_t>& links, const QString& key = "");
     /**
@@ -483,7 +492,7 @@ public:
        @param desc          the description string
        @param links         a list of links
        @param key           some key to be sent with the header links
-       @return The formated text ready to be used.
+       @return The formatted text ready to be used.
      */
     static QString createText(bool isReadOnly, const QString& desc, const QList<link_t>& links, const QString& key = "");
     /**
@@ -586,6 +595,7 @@ protected:
         ,eFlagWriteAllowed  = 0x00000002
         ,eFlagTainted       = 0x00000004
         ,eFlagWptBubble     = 0x00000100
+        ,eFlagWptNogo      = 0x00000200
     };
 
     static inline bool isBlocked(const QRectF& rect, const QList<QRectF> &blockedAreas)
