@@ -37,6 +37,9 @@ public:
 
     QString getDBInfo() const;
 
+    bool search(const QString& str, QSqlQuery &query) override;
+
+    void copyFolder(quint64 child, quint64 parent) override;
 private:
     QString filename;
     QString error;
