@@ -17,7 +17,8 @@
 **********************************************************************************************/
 
 #include "CMainWindow.h"
-#include "gis/CGisWidget.h"
+#include "gis/CGisDatabase.h"
+#include "gis/CGisWorkspace.h"
 #include "gis/db/CDBProject.h"
 #include "gis/db/CSelectSaveAction.h"
 #include "gis/db/IDB.h"
@@ -99,6 +100,7 @@ CDBProject::CDBProject(const QString& dbName, quint64 id, CGisListWks *parent)
     setupName(name);
     setToolTip(CGisListWks::eColumnName, getInfo());
     updateItems();
+
     valid = true;
 }
 
@@ -160,7 +162,7 @@ CDBProject::CDBProject(const QString& filename, IDBFolder * parentFolder, CGisLi
 CDBProject::~CDBProject()
 {
     CEvtW2DAckInfo * info = new CEvtW2DAckInfo(Qt::Unchecked, getId(), getDBName(), getDBHost());
-    CGisWidget::self().postEventForDb(info);
+    CGisDatabase::self().postEventForDb(info);
 }
 
 void CDBProject::restoreDBLink()
@@ -246,10 +248,10 @@ void CDBProject::postStatus(bool updateLostFound)
     // updateItems(); <--- don't! this is causing a crash
     if(!changedItems)
     {
-        setText(CGisListWks::eColumnDecoration,"");
+        setText(CGisListWks::eColumnDecoration,autoSave ? "A" : "");
     }
 
-    CGisWidget::self().postEventForDb(info);
+    CGisDatabase::self().postEventForDb(info);
 }
 
 
@@ -287,7 +289,9 @@ int CDBProject::checkForAction2(IGisItem * item, quint64 &itemId, QString& hashI
         QAbstractButton* pButUpdate = msgBox.addButton(tr("Take remote"),   QMessageBox::DestructiveRole);
         msgBox.addButton(QMessageBox::Abort);
 
+        CProgressDialog::setAllVisible(false);
         msgBox.exec();
+        CProgressDialog::setAllVisible(true);
 
         if(msgBox.clickedButton() == pButClone)
         {
@@ -338,7 +342,7 @@ void CDBProject::updateItem(IGisItem *&item, quint64 idItem, QSqlQuery &query)
     query.bindValue(":icon",    buffer.data());
     query.bindValue(":name",    item->getName());
     query.bindValue(":date",    item->getTimestamp());
-    query.bindValue(":comment", item->getInfo(true, true));
+    query.bindValue(":comment", item->getInfo(IGisItem::eFeatureShowName|IGisItem::eFeatureShowFullText));
     query.bindValue(":data",    data);
     query.bindValue(":hash",    item->getHash());
     query.bindValue(":id",      idItem);
@@ -386,7 +390,7 @@ void CDBProject::updateItem(IGisItem *&item, quint64 idItem, QSqlQuery &query)
             query.bindValue(":icon",    buffer.data());
             query.bindValue(":name",    item->getName());
             query.bindValue(":date",    item->getTimestamp());
-            query.bindValue(":comment", item->getInfo(true, true));
+            query.bindValue(":comment", item->getInfo(IGisItem::eFeatureShowName|IGisItem::eFeatureShowFullText));
             query.bindValue(":data",    data);
             query.bindValue(":hash",    item->getHash());
             query.bindValue(":id",      idItem);
@@ -439,7 +443,7 @@ quint64 CDBProject::insertItem(IGisItem * item, QSqlQuery &query)
     query.bindValue(":icon",    buffer.data());
     query.bindValue(":name",    item->getName());
     query.bindValue(":date",    item->getTimestamp());
-    query.bindValue(":comment", item->getInfo(true, true));
+    query.bindValue(":comment", item->getInfo(IGisItem::eFeatureShowName|IGisItem::eFeatureShowFullText));
     query.bindValue(":data",    data);
     query.bindValue(":hash",    item->getHash());
     QUERY_EXEC(throw eReasonQueryFail);
@@ -634,6 +638,7 @@ bool CDBProject::save()
         }
         catch(reasons_e reason)
         {
+            CProgressDialog::setAllVisible(false);
             switch(reason)
             {
             case eReasonQueryFail:
@@ -649,6 +654,8 @@ bool CDBProject::save()
                 i--;
                 break;
             }
+
+            CProgressDialog::setAllVisible(true);
         }
     }
 
@@ -669,7 +676,6 @@ bool CDBProject::save()
     QUERY_EXEC(return false);
 
     postStatus(true);
-
     // update change flag
     updateDecoration();
     return success;
@@ -811,7 +817,7 @@ void CDBProject::update()
             evt->items << evt_item_t(query.value(0).toULongLong(), query.value(1).toUInt());
         }
 
-        CGisWidget::self().postEventForWks(evt);
+        CGisWorkspace::self().postEventForWks(evt);
     }
     else
     {
