@@ -41,7 +41,7 @@ public:
     CGisItemOvlArea(const QDomNode &xml, IGisProject *project);
     CGisItemOvlArea(const history_t& hist, const QString& dbHash, IGisProject * project);
     CGisItemOvlArea(quint64 id, QSqlDatabase& db, IGisProject * project);
-    CGisItemOvlArea(const IQlgtOverlay& ovl);
+    CGisItemOvlArea(const IQlgtOverlay& ovl, IGisProject *project = nullptr);
     virtual ~CGisItemOvlArea();
 
     IGisItem * createClone() override;
@@ -58,7 +58,7 @@ public:
     {
         return colorIdx;
     }
-    QString getInfo(bool showName, bool showFullText) const override;
+    QString getInfo(quint32 feature) const override;
     void getPolylineFromData(SGisLine& l) override;
     const QString& getComment() const override
     {
