@@ -285,7 +285,7 @@ void CDetailsPrj::draw(QTextDocument& doc, bool printable)
     for(int i = 0; i < N; i++)
     {
         CGisItemTrk *trk = dynamic_cast<CGisItemTrk*>(prj.child(i));
-        if(nullptr != trk)
+        if(nullptr != trk && !trk->isHidden())
         {
             trks << trk;
             nItems++;
@@ -293,7 +293,7 @@ void CDetailsPrj::draw(QTextDocument& doc, bool printable)
         }
 
         CGisItemRte *rte = dynamic_cast<CGisItemRte*>(prj.child(i));
-        if(nullptr != rte)
+        if(nullptr != rte && !rte->isHidden())
         {
             rtes << rte;
             nItems++;
@@ -301,7 +301,7 @@ void CDetailsPrj::draw(QTextDocument& doc, bool printable)
         }
 
         CGisItemWpt *wpt = dynamic_cast<CGisItemWpt*>(prj.child(i));
-        if(nullptr != wpt)
+        if(nullptr != wpt && !wpt->isHidden())
         {
             wpts << wpt;
             nItems++;
@@ -309,7 +309,7 @@ void CDetailsPrj::draw(QTextDocument& doc, bool printable)
         }
 
         CGisItemOvlArea *area = dynamic_cast<CGisItemOvlArea*>(prj.child(i));
-        if(nullptr != area)
+        if(nullptr != area && !area->isHidden())
         {
             areas << area;
             nItems++;
@@ -403,24 +403,6 @@ void CDetailsPrj::addIcon(QTextTable * table, int col, int row, IGisItem * item,
 {
     table->cellAt(row,col).firstCursorPosition().insertImage(item->getIcon().toImage().scaledToWidth(16, Qt::SmoothTransformation));
 
-    CGisItemTrk * trk = dynamic_cast<CGisItemTrk*>(item);
-    if(trk)
-    {
-        QSet<QString> icons;
-        for(const CActivityTrk::activity_range_t& range : trk->getActivities().getActivityRanges())
-        {
-            icons << range.icon;
-        }
-
-        for(const QString &icon : icons)
-        {
-            if(!icon.isEmpty())
-            {
-                table->cellAt(row,col).lastCursorPosition().insertHtml(QString("<p><br/><img src='%1'/></p>").arg(icon));
-            }
-        }
-    }
-
     if(!(printable||item->isReadOnly()))
     {
         table->cellAt(row,col).lastCursorPosition().insertHtml(QString("<p><a href='edit?key=%1'><img src='://icons/16x16/EditDetails.png'/></a></p>").arg(item->getKey().item));
@@ -450,7 +432,7 @@ void CDetailsPrj::drawByGroup(QTextCursor &cursor, QList<CGisItemTrk*>& trks, QL
             PROGRESS(n++, return );
 
             addIcon(table, eSym1, cnt, wpt, printable);
-            table->cellAt(cnt,eInfo1).firstCursorPosition().insertHtml(wpt->getInfo(true, false));
+            table->cellAt(cnt,eInfo1).firstCursorPosition().insertHtml(wpt->getInfo(IGisItem::eFeatureShowName));
             table->cellAt(cnt,eComment1).firstCursorPosition().insertHtml(IGisItem::createText(wpt->isReadOnly()||printable, wpt->getComment(), wpt->getDescription(), wpt->getLinks(), wpt->getKey().item));
             cnt++;
         }
@@ -483,7 +465,7 @@ void CDetailsPrj::drawByGroup(QTextCursor &cursor, QList<CGisItemTrk*>& trks, QL
 
             if(w1 < 300)
             {
-                table->cellAt(cnt,eInfo1).firstCursorPosition().insertHtml(trk->getInfo(true, false));
+                table->cellAt(cnt,eInfo1).firstCursorPosition().insertHtml(trk->getInfo(IGisItem::eFeatureShowName|IGisItem::eFeatureShowActivity));
 
                 QTextTable * table1 = table->cellAt(cnt,eInfo1).lastCursorPosition().insertTable(1, 2, fmtTableInfo);
 
@@ -499,7 +481,7 @@ void CDetailsPrj::drawByGroup(QTextCursor &cursor, QList<CGisItemTrk*>& trks, QL
             {
                 QTextTable * table1 = table->cellAt(cnt,eInfo1).firstCursorPosition().insertTable(1, 3, fmtTableInfo);
 
-                table1->cellAt(0,0).firstCursorPosition().insertHtml(trk->getInfo(true, false));
+                table1->cellAt(0,0).firstCursorPosition().insertHtml(trk->getInfo(IGisItem::eFeatureShowName|IGisItem::eFeatureShowActivity));
 
                 QImage profile(w1,h1,QImage::Format_ARGB32);
                 getTrackProfile(trk, profile);
@@ -601,7 +583,7 @@ void CDetailsPrj::drawByTrack(QTextCursor& cursor, QList<CGisItemTrk *> &trks, Q
             if(wpt != nullptr)
             {
                 addIcon(table, eSym2, cnt, wpt, printable);
-                table->cellAt(cnt,eInfo2).firstCursorPosition().insertHtml(wpt->getInfo(true, false));
+                table->cellAt(cnt,eInfo2).firstCursorPosition().insertHtml(wpt->getInfo(IGisItem::eFeatureShowName));
 
                 QTextTable * table1 = table->cellAt(cnt,eData2).lastCursorPosition().insertTable(1, 2, fmtTableInfo);
 
@@ -610,7 +592,7 @@ void CDetailsPrj::drawByTrack(QTextCursor& cursor, QList<CGisItemTrk *> &trks, Q
                 text += "<tr><td></td><td><nobr>&nbsp;" + tr("From Start") + "&nbsp;</nobr></td><td><nobr>&nbsp;" + tr("To Next") + "&nbsp;</nobr></td><td><nobr>&nbsp;" + tr("To End")  + "&nbsp;</nobr></td></tr>";
 
                 text += "<tr>";
-                text += "<td>" + tr("distance: ") + "</td>";
+                text += "<td>" + tr("Distance: ") + "</td>";
                 IUnit::self().meter2distance(info.distance1, val, unit);
                 text += "<td>"+ QString("%1%2").arg(val).arg(unit) + "</td>";
                 IUnit::self().meter2distance(info.distance2, val, unit);
@@ -620,7 +602,7 @@ void CDetailsPrj::drawByTrack(QTextCursor& cursor, QList<CGisItemTrk *> &trks, Q
                 text += "</tr>";
 
                 text += "<tr>";
-                text += "<td>" + tr("ascent: ") + "</td>";
+                text += "<td>" + tr("Ascent: ") + "</td>";
                 IUnit::self().meter2elevation(info.ascent1, val, unit);
                 text += "<td>"+ QString("%1%2").arg(val).arg(unit) + "</td>";
                 IUnit::self().meter2elevation(info.ascent2, val, unit);
@@ -630,7 +612,7 @@ void CDetailsPrj::drawByTrack(QTextCursor& cursor, QList<CGisItemTrk *> &trks, Q
                 text += "</tr>";
 
                 text += "<tr>";
-                text += "<td>" + tr("descent: ") + "</td>";
+                text += "<td>" + tr("Descent: ") + "</td>";
                 IUnit::self().meter2elevation(info.descent1, val, unit);
                 text += "<td>"+ QString("%1%2").arg(val).arg(unit) + "</td>";
                 IUnit::self().meter2elevation(info.descent2, val, unit);
@@ -675,7 +657,7 @@ void CDetailsPrj::drawByTrack(QTextCursor& cursor, QList<CGisItemTrk *> &trks, Q
         }
 
         addIcon(table, eSym1, cnt, trk, printable);
-        table->cellAt(cnt,eInfo2).firstCursorPosition().insertHtml(trk->getInfo(true, false));
+        table->cellAt(cnt,eInfo2).firstCursorPosition().insertHtml(trk->getInfo(IGisItem::eFeatureShowName|IGisItem::eFeatureShowActivity));
 
         QTextTable * table1 = table->cellAt(cnt,eData2).lastCursorPosition().insertTable(1, 2, fmtTableInfo);
 
@@ -715,7 +697,7 @@ void CDetailsPrj::drawArea(QTextCursor& cursor, QList<CGisItemOvlArea *> &areas,
         PROGRESS(n++, return );
 
         addIcon(table, eSym1, cnt, area, printable);
-        table->cellAt(cnt,eInfo1).firstCursorPosition().insertHtml(area->getInfo(true, false));
+        table->cellAt(cnt,eInfo1).firstCursorPosition().insertHtml(area->getInfo(IGisItem::eFeatureShowName));
         table->cellAt(cnt,eComment1).firstCursorPosition().insertHtml(IGisItem::createText(area->isReadOnly()||printable, area->getComment(), area->getDescription(), area->getLinks(), area->getKey().item));
         cnt++;
     }
@@ -745,7 +727,7 @@ void CDetailsPrj::drawRoute(QTextCursor& cursor, QList<CGisItemRte *> &rtes, CPr
         PROGRESS(n++, return );
 
         addIcon(table, eSym1, cnt, rte, printable);
-        table->cellAt(cnt,eInfo1).firstCursorPosition().insertHtml(rte->getInfo(true, false));
+        table->cellAt(cnt,eInfo1).firstCursorPosition().insertHtml(rte->getInfo(IGisItem::eFeatureShowName));
         table->cellAt(cnt,eComment1).firstCursorPosition().insertHtml(IGisItem::createText(rte->isReadOnly()||printable, rte->getComment(), rte->getDescription(), rte->getLinks(), rte->getKey().item));
         cnt++;
     }
