@@ -1,5 +1,6 @@
 /**********************************************************************************************
     Copyright (C) 2014 Oliver Eichler oliver.eichler@gmx.de
+    Copyright (C) 2017 Norbert Truchsess norbert.truchsess@t-online.de
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,15 +21,20 @@
 #include "device/IDevice.h"
 #include "gis/CGisDraw.h"
 #include "gis/CGisListWks.h"
+#include "gis/CGisWorkspace.h"
 #include "gis/IGisItem.h"
 #include "gis/fit/CFitProject.h"
 #include "gis/gpx/CGpxProject.h"
 #include "gis/ovl/CGisItemOvlArea.h"
 #include "gis/prj/CDetailsPrj.h"
 #include "gis/prj/IGisProject.h"
+#include "gis/qlb/CQlbProject.h"
 #include "gis/qms/CQmsProject.h"
 #include "gis/rte/CGisItemRte.h"
+#include "gis/rte/router/IRouter.h"
 #include "gis/slf/CSlfProject.h"
+#include "gis/suunto/CLogProject.h"
+#include "gis/suunto/CSmlProject.h"
 #include "gis/tcx/CTcxProject.h"
 #include "gis/tcx/CTcxProject.h"
 #include "gis/trk/CGisItemTrk.h"
@@ -40,14 +46,17 @@
 #include <QtWidgets>
 
 
-const QString IGisProject::filedialogAllSupported = "All Supported (*.gpx *.GPX *.tcx *.TCX *.qms *.slf *.fit)";
+const QString IGisProject::filedialogAllSupported = "All Supported (*.gpx *.GPX *.tcx *.TCX *.sml *.log *.qms *.qlb *.slf *.fit)";
 const QString IGisProject::filedialogFilterGPX    = "GPS Exchange Format (*.gpx *.GPX)";
 const QString IGisProject::filedialogFilterTCX    = "TCX Garmin Proprietary (*.tcx *.TCX)";
+const QString IGisProject::filedialogFilterSML    = "Suunto XML format (*.sml)";
+const QString IGisProject::filedialogFilterLOG    = "Openambit XML format (*.log)";
+const QString IGisProject::filedialogFilterQLB    = "QLandkarte Binary (*.qlb)";
 const QString IGisProject::filedialogFilterQMS    = "QMapShack Binary (*.qms)";
 const QString IGisProject::filedialogFilterSLF    = "Sigma Log Format (*.slf)";
 const QString IGisProject::filedialogFilterFIT    = "Garmin FIT Format (*.fit)";
-const QString IGisProject::filedialogSaveFilters = filedialogFilterGPX + ";; " + filedialogFilterQMS + ";; " + filedialogFilterTCX;
-const QString IGisProject::filedialogLoadFilters = filedialogAllSupported + ";; " + filedialogFilterGPX + ";; " + filedialogFilterTCX + ";; " + filedialogFilterQMS + ";; " + filedialogFilterSLF + ";;" + filedialogFilterFIT;
+const QString IGisProject::filedialogSaveFilters = filedialogFilterGPX + ";; " + filedialogFilterQLB + ";; " + filedialogFilterQMS + ";; " + filedialogFilterTCX;
+const QString IGisProject::filedialogLoadFilters = filedialogAllSupported + ";; " + filedialogFilterGPX + ";; " + filedialogFilterTCX + ";; " + filedialogFilterSML + ";; " + filedialogFilterLOG + ";; " + filedialogFilterQLB + ";; " + filedialogFilterQMS + ";; " + filedialogFilterSLF + ";; " + filedialogFilterFIT;
 
 IGisProject::filter_mode_e IGisProject::filterMode = IGisProject::eFilterModeName;
 
@@ -57,7 +66,7 @@ IGisProject::IGisProject(type_e type, const QString &filename, CGisListWks *pare
     , filename(filename)
 {
     memset(cntItemsByType, 0, sizeof(cntItemsByType));
-    setCheckState(CGisListWks::eColumnDecoration, Qt::Checked);
+    setCheckState(CGisListWks::eColumnCheckBox, Qt::Checked);
 
     if(parent)
     {
@@ -89,7 +98,7 @@ IGisProject::IGisProject(type_e type, const QString &filename, IDevice *parent)
     , filename(filename)
 {
     memset(cntItemsByType, 0, sizeof(cntItemsByType));
-    setCheckState(CGisListWks::eColumnDecoration, Qt::Checked);
+    setCheckState(CGisListWks::eColumnCheckBox, Qt::Checked);
     nameSuffix = parent->getName();
 }
 
@@ -129,7 +138,18 @@ IGisProject * IGisProject::create(const QString filename, CGisListWks * parent)
     {
         item = new CTcxProject(filename, parent);
     }
-
+    else if (suffix == "sml")
+    {
+        item = new CSmlProject(filename, parent);
+    }
+    else if (suffix == "log")
+    {
+        item = new CLogProject(filename, parent);
+    }
+    else if (suffix == "qlb")
+    {
+        item = new CQlbProject(filename, parent);
+    }
 
     if(item && !item->isValid())
     {
@@ -175,9 +195,10 @@ bool IGisProject::askBeforClose()
 
 bool IGisProject::isVisible() const
 {
-    return checkState(CGisListWks::eColumnDecoration) == Qt::Checked;
+    return checkState(CGisListWks::eColumnCheckBox) == Qt::Checked;
 }
 
+
 void IGisProject::genKey() const
 {
     if(key.isEmpty())
@@ -286,10 +307,35 @@ void IGisProject::setSortingFolder(sorting_folder_e s)
 
 void IGisProject::setChanged()
 {
-    setText(CGisListWks::eColumnDecoration,"*");
+    if(autoSave)
+    {
+        setText(CGisListWks::eColumnDecoration,"A");
+
+        if(!autoSavePending)
+        {
+            autoSavePending = true;
+            CGisWorkspace::self().postEventForWks(new CEvtA2WSave(getKey()));
+        }
+    }
+    else
+    {
+        setText(CGisListWks::eColumnDecoration,"*");
+    }
     updateItems();
 }
 
+void IGisProject::setAutoSave(bool on)
+{
+    // make sure project is saved one more time to remove autoSave flag in storage
+    if(!on && autoSave)
+    {
+        CGisWorkspace::self().postEventForWks(new CEvtA2WSave(getKey()));
+    }
+
+    autoSave = on;
+    setChanged();
+}
+
 void IGisProject::switchOnCorrelation()
 {
     noCorrelation = false;
@@ -465,7 +511,7 @@ void IGisProject::setupName(const QString &defaultName)
 
 void IGisProject::markAsSaved()
 {
-    setText(CGisListWks::eColumnDecoration,"");
+    setText(CGisListWks::eColumnDecoration,autoSave ? "A" : "");
     for(int i = 0; i < childCount(); i++)
     {
         IGisItem * item = dynamic_cast<IGisItem*>(child(i));
@@ -627,6 +673,29 @@ void IGisProject::getItemsByArea(const QRectF& area, IGisItem::selflags_t flags,
     }
 }
 
+void IGisProject::getNogoAreas(QVector<IRouter::circle_t> &areas) const
+{
+    if(!isVisible())
+    {
+        return;
+    }
+
+    for(int i = 0; i < childCount(); i++)
+    {
+        CGisItemWpt * item = dynamic_cast<CGisItemWpt*>(child(i));
+        if(nullptr != item && !item->isHidden() && item->isNogoArea())
+        {
+            const qreal& rad = item->getProximity();
+            if (rad != NOFLOAT && rad > 0.)
+            {
+                const QPointF& pos = item->getPosition();
+                areas << IRouter::circle_t(pos.y(),pos.x(),rad);
+            }
+        }
+    }
+}
+
+
 void IGisProject::mouseMove(const QPointF& pos)
 {
     if(!isVisible())
@@ -1006,8 +1075,7 @@ void IGisProject::updateDecoration()
             break;
         }
     }
-
-    setText(CGisListWks::eColumnDecoration, saved ? "" : "*");
+    setText(CGisListWks::eColumnDecoration, autoSave ? "A" : saved ? "" : "*");
 }
 
 void IGisProject::sortItems()
@@ -1075,14 +1143,26 @@ void IGisProject::sortItems()
     addChildren(items);
 }
 
-bool sortByName(IGisItem * item1, IGisItem * item2)
+static bool sortByName(IGisItem * item1, IGisItem * item2)
 {
-    return item1->getName() < item2->getName();
+    static QCollator collator;
+    // this will set collator to natural sorting mode (instead of lexical)
+    collator.setNumericMode(true);
+    return collator.compare(item1->getName(), item2->getName()) < 0;
 }
 
-bool sortByTime(IGisItem * item1, IGisItem * item2)
+static bool sortByTime(IGisItem * item1, IGisItem * item2)
 {
-    return item1->getTimestamp() < item2->getTimestamp();
+    const QDateTime& t1 = item1->getTimestamp();
+    const QDateTime& t2 = item2->getTimestamp();
+
+    // avoid jumping items due to invalid timestamps
+    if(!t1.isValid() || !t2.isValid())
+    {
+        return sortByName(item1, item2);
+    }
+
+    return t1 < t2;
 }
 
 void IGisProject::sortItems(QList<IGisItem *> &items) const
@@ -1127,7 +1207,7 @@ void IGisProject::filter(const QString& str)
             break;
 
         case eFilterModeText:
-            item->setHidden(!item->getInfo(true, true).toUpper().contains(str));
+            item->setHidden(!item->getInfo(IGisItem::eFeatureShowName|IGisItem::eFeatureShowFullText).toUpper().contains(str));
             break;
         }
     }
