@@ -604,7 +604,7 @@ QDataStream& CGisItemTrk::operator<<(QDataStream& stream)
     deriveSecondaryData();
     setColor(str2color(trk.color));
     setText(   CGisListWks::eColumnName, getName());
-    setToolTip(CGisListWks::eColumnName, getInfo(true, false));
+    setToolTip(CGisListWks::eColumnName, getInfo(IGisItem::eFeatureShowName));
     return stream;
 }
 
@@ -646,7 +646,10 @@ QDataStream& CGisItemWpt::operator<<(QDataStream& stream)
 
     setIcon();
     setText   (CGisListWks::eColumnName, getName());
-    setToolTip(CGisListWks::eColumnName, getInfo(true, false));
+    setToolTip(CGisListWks::eColumnName, getInfo(IGisItem::eFeatureShowName));
+
+    detBoundingRect();
+    radius = NOFLOAT;
 
     return stream;
 }
@@ -725,7 +728,7 @@ QDataStream& CGisItemRte::operator<<(QDataStream& stream)
     setSymbol();
     deriveSecondaryData();
     setText   (CGisListWks::eColumnName, getName());
-    setToolTip(CGisListWks::eColumnName, getInfo(true, false));
+    setToolTip(CGisListWks::eColumnName, getInfo(IGisItem::eFeatureShowName));
 
     return stream;
 }
@@ -805,7 +808,7 @@ QDataStream& CGisItemOvlArea::operator<<(QDataStream& stream)
 
     setColor(str2color(area.color));
     setText   (CGisListWks::eColumnName, getName());
-    setToolTip(CGisListWks::eColumnName, getInfo(true, false));
+    setToolTip(CGisListWks::eColumnName, getInfo(IGisItem::eFeatureShowName));
 
     return stream;
 }
@@ -888,7 +891,8 @@ QDataStream& IGisProject::operator<<(QDataStream& stream)
     {
         qint8 tmp;
         stream >> tmp;
-        noCorrelation = tmp != 0;
+        noCorrelation   = (tmp & eFlagNoCorrelation) != 0;
+        autoSave        = (tmp & eFlagAutoSave) != 0;
     }
 
     if(version > 4)
@@ -969,7 +973,7 @@ QDataStream& IGisProject::operator>>(QDataStream& stream) const
     stream << metadata.bounds;
     stream << key;
     stream << qint32(sortingRoadbook);
-    stream << qint8(noCorrelation);
+    stream << qint8((noCorrelation ? eFlagNoCorrelation : 0) | (autoSave ? eFlagAutoSave : 0)); // collect trivial flags in one field.
     stream << qint32(sortingFolder);
 
     for(int i = 0; i < childCount(); i++)
@@ -1067,7 +1071,8 @@ QDataStream& CDBProject::operator<<(QDataStream& stream)
     {
         qint8 tmp;
         stream >> tmp;
-        noCorrelation = tmp != 0;
+        noCorrelation   = (tmp & eFlagNoCorrelation) != 0;
+        autoSave        = (tmp & eFlagAutoSave) != 0;
     }
     if(version > 4)
     {
@@ -1095,7 +1100,7 @@ QDataStream& CDBProject::operator>>(QDataStream& stream) const
     stream << metadata.bounds;
     stream << key;
     stream << qint32(sortingRoadbook);
-    stream << qint8(noCorrelation);
+    stream << qint8((noCorrelation ? eFlagNoCorrelation : 0) | (autoSave ? eFlagAutoSave : 0)); // collect trivial flags in one field.
     stream << qint32(sortingFolder);
 
     return stream;
