@@ -35,7 +35,7 @@ public:
     CScrOptRte(CGisItemRte * rte, const QPoint &point, IMouse *parent);
     virtual ~CScrOptRte();
 
-    void draw(QPainter& p);
+    void draw(QPainter& p) override;
 
 private slots:
     void slotEditDetails();
@@ -45,6 +45,7 @@ private slots:
     void slotReset();
     void slotEdit();
     void slotInstruction(bool on);
+    void slotToTrack();
 
 private:
     IGisItem::key_t key;
