@@ -131,7 +131,6 @@ CDetailsTrk::CDetailsTrk(CGisItemTrk& trk, QWidget *parent)
     connect(textCmtDesc,      &QTextBrowser::anchorClicked,        this, &CDetailsTrk::slotLinkActivated);
 
     connect(pushSetActivities,    &QPushButton::clicked, this, &CDetailsTrk::slotSetActivities);
-    connect(pushRemoveActivities, &QPushButton::clicked, this, &CDetailsTrk::slotRemoveActivities);
 
     connect(lineName,         &QLineEdit::textEdited,              this, &CDetailsTrk::slotNameChanged);
     connect(lineName,         &QLineEdit::editingFinished,         this, &CDetailsTrk::slotNameChangeFinished);
@@ -162,7 +161,7 @@ CDetailsTrk::CDetailsTrk(CGisItemTrk& trk, QWidget *parent)
     // setting up the graph properties will trigger the signals
     // this is good because the signals are connected at this point
     // invoking the slots
-    loadGraphSource(comboGraph2, 2, CKnownExtension::internalSpeed);
+    loadGraphSource(comboGraph2, 2, CKnownExtension::internalSpeedDist);
     loadGraphSource(comboGraph3, 3, CKnownExtension::internalProgress);
 
     addFilterGroup<CFilterDouglasPeuker, CFilterInvalid, CFilterReset, CFilterDelete>
@@ -351,11 +350,10 @@ void CDetailsTrk::updateData()
     bool isReadOnly = trk.isReadOnly();
 
     tabWidget->widget(eTabFilter)->setEnabled(!isReadOnly);
-    tabWidget->widget(eTabActivity)->setEnabled(!isReadOnly);
 
     labelTainted->setVisible(trk.isTainted());
 
-    labelInfo->setText(trk.getInfo(false, false));
+    labelInfo->setText(trk.getInfo(IGisItem::eFeatureNone));
     comboColor->setCurrentIndex(trk.getColorIdx());
     toolLock->setChecked(isReadOnly);
 
@@ -375,6 +373,7 @@ void CDetailsTrk::updateData()
     bool hasActivity = 0 != (flags & CTrackData::trkpt_t::eActMask);
     labelActivityHelp->setVisible(!hasActivity);
     labelActivityInfo->setVisible(hasActivity);
+    pushSetActivities->setEnabled(!isReadOnly);
 
     plotTrack->setTrack(&trk);
     listHistory->setupHistory(trk);
@@ -406,7 +405,7 @@ void CDetailsTrk::updateData()
     {
         const CKnownExtension &ext = CKnownExtension::get(key);
         QIcon icon(ext.icon);
-        comboColorSource->addItem(icon, ext.known ? ext.name : key, key);
+        comboColorSource->addItem(icon, ext.known ? ext.nameLongText : key, key);
     }
     int currentIdx = comboColorSource->findData(trk.getColorizeSource());
     if(-1 == currentIdx)
@@ -453,7 +452,7 @@ void CDetailsTrk::updateData()
     X_____________UnBlockAllSignals_____________X(this);
 
     // refill comboboxes to select track property to be displayed by graphs
-    loadGraphSource(comboGraph2, 2, CKnownExtension::internalSpeed);
+    loadGraphSource(comboGraph2, 2, CKnownExtension::internalSpeedDist);
     loadGraphSource(comboGraph3, 3, CKnownExtension::internalProgress);
 
     CFilterDeleteExtension *filter = treeFilter->findChild<CFilterDeleteExtension*>();
@@ -622,20 +621,12 @@ void CDetailsTrk::slotLinkActivated(const QUrl& url)
 void CDetailsTrk::slotSetActivities()
 {
     quint32 flags = CActivityTrk::selectActivity(this);
-    if(0 != flags)
+    if(0xFFFFFFFF != flags)
     {
         trk.setActivity(flags);
     }
 }
 
-void CDetailsTrk::slotRemoveActivities()
-{
-    if(QMessageBox::warning(this, tr("Reset activities..."), tr("This will remove all activities from the track. Proceed?"), QMessageBox::Ok|QMessageBox::No, QMessageBox::Ok) == QMessageBox::Ok)
-    {
-        trk.setActivity(CTrackData::trkpt_t::eActNone);
-    }
-}
-
 void CDetailsTrk::setupGraph(CPlot * plot, const CLimit& limit, const QString& source, QDoubleSpinBox * spinMin, QDoubleSpinBox * spinMax)
 {
     trk.getPropertyHandler()->setupPlot(plot, source);
