@@ -19,7 +19,7 @@
 #include "CMainWindow.h"
 #include "GeoMath.h"
 #include "gis/CGisDraw.h"
-#include "gis/CGisWidget.h"
+#include "gis/CGisWorkspace.h"
 #include "gis/prj/IGisProject.h"
 #include "gis/trk/CCutTrk.h"
 #include "gis/trk/CDetailsTrk.h"
@@ -36,8 +36,6 @@
 #include <QtXml>
 #include <proj_api.h>
 
-using std::numeric_limits;
-
 #define DEFAULT_COLOR       4
 #define MIN_DIST_CLOSE_TO   10
 #define MIN_DIST_FOCUS      200
@@ -120,6 +118,18 @@ CGisItemTrk::CGisItemTrk(const QDomNode& xml, IGisProject *project)
 
     setupHistory();
     updateDecoration(eMarkNone, eMarkNone);
+
+    if((cntInvalidPoints != 0) && (cntInvalidPoints < cntVisiblePoints))
+    {
+        int res = QMessageBox::question(CMainWindow::self().getBestWidgetForParent(), tr("Invalid points...."),
+                                        tr("The track '%1' has %2 invalid points out of %3 visible points. "
+                                           "Do you want to hide invalid points now?").arg(getName()).arg(cntInvalidPoints).arg(cntVisiblePoints),
+                                        QMessageBox::Yes|QMessageBox::No, QMessageBox::No);
+        if(res == QMessageBox::Yes)
+        {
+            filterRemoveInvalidPoints();
+        }
+    }
 }
 
 CGisItemTrk::CGisItemTrk(const QString& filename, IGisProject * project)
@@ -281,13 +291,58 @@ void CGisItemTrk::unregisterVisual(INotifyTrk * visual)
     registeredVisuals.remove(visual);
 }
 
-QString CGisItemTrk::getInfo(bool showName, bool showFullText) const
+static void addRowLimit(QString& str, const QString& name, const QString& min, const QString& max)
+{
+    str += "<tr>";
+    str += "<td align='left'>" + name + "</td>";
+    str += "<td align='right'>" + min + "</td>";
+    str += "<td align='right'>" + max + "</td>";
+    str += "</tr>";
+}
+
+static bool sortByName(const QString& item1, const QString& item2)
+{
+    static QCollator collator;
+    // this will set collator to natural sorting mode (instead of lexical)
+    collator.setNumericMode(true);
+    return collator.compare(item1, item2) < 0;
+}
+
+
+QString CGisItemTrk::getInfoLimits() const
+{
+    QString str = "<table width='100%'>";
+
+    str += "<tr><th align='left'></th><th align='right'>" + tr("min.") + "</th><th align='right'>" + tr("max.") + "</th></tr>";
+
+    QStringList keys = extrema.keys();
+    qSort(keys.begin(), keys.end(), sortByName);
+
+    for(const QString& key : keys)
+    {
+        const CKnownExtension& ext = CKnownExtension::get(key);
+        const limits_t& limit = extrema[key];
+
+        const QString& labelMin = ext.toString(limit.min, false, key);
+        const QString& labelMax = ext.toString(limit.max, false, key);
+
+        if(!labelMin.isEmpty() && !labelMax.isEmpty())
+        {
+            addRowLimit(str, ext.getName(key), labelMin, labelMax);
+        }
+    }
+
+    str += "</table>";
+    return str;
+}
+
+QString CGisItemTrk::getInfo(quint32 feature) const
 {
     QString val1, unit1, val2, unit2;
 
     if(cntVisiblePoints == 0)
     {
-        return showName ? QString("<div><b>%1</b></div>").arg(getName()) : QString("<div></div>");
+        return feature ? QString("<div><b>%1</b></div>").arg(getName()) : QString("<div></div>");
     }
 
     bool timeIsValid = (allValidFlags & CTrackData::trkpt_t::eInvalidTime) == 0;
@@ -296,50 +351,70 @@ QString CGisItemTrk::getInfo(bool showName, bool showFullText) const
 
     QString str = "<div>";
 
-    if(showName)
+    qint32 actCnt       = activities.getActivityCount();
+    quint32 actFlags    = activities.getAllFlags();
+
+    if(feature & eFeatureShowName)
     {
-        str += "<b>" + getName() + "</b><br />";
+        if((actCnt == 1) && actFlags)
+        {
+            const CActivityTrk::desc_t& desc = activities.getDescriptor(actFlags);
+            str += QString("<img src='%1'/>&nbsp;").arg(desc.iconSmall);
+        }
+        str += "<b>" + getName() + "</b>";
     }
 
-    IUnit::self().meter2distance(totalDistance, val1, unit1);
-    str += tr("Length: %1 %2").arg(val1).arg(unit1);
-
-    if(eleIsValid && totalAscent != NOFLOAT && totalDescent != NOFLOAT)
+    if((feature & eFeatureShowActivity) && (actCnt > 1))
     {
-        IUnit::self().meter2elevation(totalAscent,  val1, unit1);
-        IUnit::self().meter2elevation(totalDescent, val2, unit2);
-
-        str += tr(", %1%2 %3, %4%5 %6").arg(QChar(0x2197)).arg(val1).arg(unit1).arg(QChar(0x2198)).arg(val2).arg(unit2);
+        str += "<br/>";
+        activities.printSummary(str);
+        str += "<br/>";
     }
     else
     {
-        str += tr(", %1-, %2-").arg(QChar(0x2197)).arg(QChar(0x2198));
-    }
-    str += "<br />";
+        str += "<br/>";
+        IUnit::self().meter2distance(totalDistance, val1, unit1);
+        str += tr("Length: %1%2").arg(val1).arg(unit1);
 
-    if(timeIsValid && (totalElapsedSeconds != NOTIME))
-    {
-        IUnit::self().seconds2time(totalElapsedSeconds, val1, unit1);
-        IUnit::self().meter2speed(totalDistance / totalElapsedSeconds, val2, unit2);
-        str += tr("Time: %1, Speed: %2 %3").arg(val1).arg(val2).arg(unit2);
-    }
-    else
-    {
-        str += tr("Time: -, Speed: -");
-    }
-    str += "<br />";
+        if(eleIsValid && totalAscent != NOFLOAT && totalDescent != NOFLOAT)
+        {
+            IUnit::self().meter2elevation(totalAscent,  val1, unit1);
+            IUnit::self().meter2elevation(totalDescent, val2, unit2);
 
-    if(timeIsValid && (totalElapsedSecondsMoving != NOTIME))
-    {
-        IUnit::self().seconds2time(totalElapsedSecondsMoving, val1, unit1);
-        IUnit::self().meter2speed(totalDistance / totalElapsedSecondsMoving, val2, unit2);
-        str += tr("Moving: %1, Speed: %2 %3").arg(val1).arg(val2).arg(unit2);
+            str += tr(", %1%2%3, %4%5%6").arg(QChar(0x2197)).arg(val1).arg(unit1).arg(QChar(0x2198)).arg(val2).arg(unit2);
+        }
+        else
+        {
+            str += tr(", %1-, %2-").arg(QChar(0x2197)).arg(QChar(0x2198));
+        }
+        str += "<br />";
+
+        if(timeIsValid && (totalElapsedSeconds != NOTIME))
+        {
+            IUnit::self().seconds2time(totalElapsedSeconds, val1, unit1);
+            IUnit::self().meter2speed(totalDistance / totalElapsedSeconds, val2, unit2);
+            str += tr("Time: %1%2, Speed: %3%4").arg(val1).arg(unit1).arg(val2).arg(unit2);
+        }
+        else
+        {
+            str += tr("Time: -, Speed: -");
+        }
+        str += "<br />";
+
+        if(timeIsValid && (totalElapsedSecondsMoving != NOTIME))
+        {
+            IUnit::self().seconds2time(totalElapsedSecondsMoving, val1, unit1);
+            IUnit::self().meter2speed(totalDistance / totalElapsedSecondsMoving, val2, unit2);
+            str += tr("Moving: %1%2, Speed: %3%4").arg(val1).arg(unit1).arg(val2).arg(unit2);
+        }
+        else
+        {
+            str += tr("Moving: -, Speed: -");
+        }
+        str += "<br />";
     }
-    else
-    {
-        str += tr("Moving: -, Speed: -");
-    }
-    str += "<br />";
+
+    str += "<br/>";
 
     if(timeIsValid && timeStart.isValid())
     {
@@ -378,7 +453,7 @@ QString CGisItemTrk::getInfo(bool showName, bool showFullText) const
         str += "<b style='color: red;'>" + tr("Invalid positions!") + "</b><br/>";
     }
 
-    if(showFullText)
+    if(feature & eFeatureShowFullText)
     {
         QStringList actNames;
         activities.getActivityNames(actNames);
@@ -407,12 +482,14 @@ QString CGisItemTrk::getInfo(bool showName, bool showFullText) const
             str += cmt;
         }
     }
+
+
     return str + "</div>";
 }
 
 QString CGisItemTrk::getInfoRange() const
 {
-    qreal tmp, slope1, slope2;
+    qreal tmp, slope1;
     QString str, val, unit;
     if((mouseRange1 == nullptr) || (mouseRange2 == nullptr) || (mouseRange1 == mouseRange2))
     {
@@ -460,10 +537,12 @@ QString CGisItemTrk::getInfoRange() const
 
     tmp    = qAtan(deltaAscent / distance);
     slope1 = qAbs(tmp * 360.0 / (2 * M_PI));
-    slope2 = qTan(slope1 * DEG_TO_RAD) * 100;
+    QString val2, unit2;
+    IUnit::self().slope2string(slope1, val2, unit2);
+
 
     IUnit::self().meter2elevation(deltaAscent, val, unit);
-    str += QString("%3 %1%2 (%4%5, %6%)").arg(val).arg(unit).arg(QChar(0x2197)).arg(qRound(slope1)).arg(QChar(0260)).arg(qRound(slope2));
+    str += QString("%3 %1%2 (%4%5)").arg(val).arg(unit).arg(QChar(0x2197)).arg(val2).arg(unit2);
     if(timeIsValid)
     {
         IUnit::self().meter2speed(deltaAscent/deltaTime, val, unit);
@@ -473,10 +552,10 @@ QString CGisItemTrk::getInfoRange() const
 
     tmp    = qAtan(deltaDescent/distance);
     slope1 = qAbs(tmp * 360.0/(2 * M_PI));
-    slope2 = qTan(slope1 * DEG_TO_RAD) * 100;
+    IUnit::self().slope2string(slope1, val2, unit2);
 
     IUnit::self().meter2elevation(deltaDescent, val, unit);
-    str += QString("%3 %1%2 (%4%5, %6%)").arg(val).arg(unit).arg(QChar(0x2198)).arg(qRound(slope1)).arg(QChar(0260)).arg(qRound(slope2));
+    str += QString("%3 %1%2 (%4%5)").arg(val).arg(unit).arg(QChar(0x2198)).arg(val2).arg(unit2);
     if(timeIsValid)
     {
         IUnit::self().meter2speed(deltaDescent/deltaTime, val, unit);
@@ -507,15 +586,16 @@ QString CGisItemTrk::getInfoTrkPt(const CTrackData::trkpt_t& pt) const
     }
 
     IUnit::self().meter2elevation(pt.ele, val1, unit1);
-    str += tr("Ele.: %1 %2").arg(val1).arg(unit1);
+    str += tr("Ele.: %1%2").arg(val1).arg(unit1);
     if(pt.slope1 != NOFLOAT)
     {
-        str += tr(" slope: %1%3 (%2%)").arg(pt.slope1, 2, 'f', 0).arg(pt.slope2, 2, 'f', 0).arg(QChar(0260));
+        IUnit::self().slope2string(pt.slope1, val1, unit1);
+        str += tr(", Slope: %1%2").arg(val1).arg(unit1);
     }
     if(pt.speed != NOFLOAT)
     {
         IUnit::self().meter2speed(pt.speed, val1, unit1);
-        str += tr(" speed: %1%2").arg(val1).arg(unit1);
+        str += tr(", Speed: %1%2").arg(val1).arg(unit1);
     }
 
     QStringList keys = pt.extensions.keys();
@@ -532,7 +612,7 @@ QString CGisItemTrk::getInfoTrkPt(const CTrackData::trkpt_t& pt) const
         const CKnownExtension &ext = CKnownExtension::get(key);
         if(ext.known)
         {
-            str += "\n" + ext.name + ": " + QString("%1%2").arg(ext.valueFunc(pt)*ext.factor, 0, 'f', 1).arg(ext.unit);
+            str += "\n" + ext.nameLongText + ": " + QString("%1%2").arg(ext.valueFunc(pt)*ext.factor, 0, 'f', 1).arg(ext.unit);
         }
         else
         {
@@ -567,7 +647,7 @@ QString CGisItemTrk::getInfoProgress(const CTrackData::trkpt_t& pt) const
     if(pt.descent != NOFLOAT)
     {
         IUnit::self().meter2elevation(pt.descent, val, unit);
-        dsc = tr(" Descent: %1%2 (%3%)").arg(val).arg(unit).arg(pt.descent * 100/totalDescent, 2, 'f', 0);
+        dsc = tr(", Descent: %1%2 (%3%)").arg(val).arg(unit).arg(pt.descent * 100/totalDescent, 2, 'f', 0);
     }
 
     if(pt.distance != NOFLOAT)
@@ -579,10 +659,10 @@ QString CGisItemTrk::getInfoProgress(const CTrackData::trkpt_t& pt) const
     if(pt.elapsedSeconds != NOFLOAT)
     {
         IUnit::self().seconds2time(pt.elapsedSecondsMoving, val, unit);
-        mov = tr(" Moving: %1%2 (%3%)").arg(val).arg(unit).arg(pt.elapsedSecondsMoving * 100/totalElapsedSecondsMoving, 2, 'f', 0);
+        mov = tr(", Moving: %1%2 (%3%)").arg(val).arg(unit).arg(pt.elapsedSecondsMoving * 100/totalElapsedSecondsMoving, 2, 'f', 0);
     }
 
-    return QString("%1 %2\n%3 %4").arg(asc).arg(dsc).arg(dst).arg(mov);
+    return QString("%1%2\n%3%4").arg(asc).arg(dsc).arg(dst).arg(mov);
 }
 
 QString CGisItemTrk::getInfoRange(const CTrackData::trkpt_t& pt1, const CTrackData::trkpt_t& pt2) const
@@ -613,7 +693,7 @@ QString CGisItemTrk::getInfoRange(const CTrackData::trkpt_t& pt1, const CTrackDa
     if((pt1.descent != NOFLOAT) && (pt2.descent != NOFLOAT))
     {
         IUnit::self().meter2elevation(pt2.descent - pt1.descent, val, unit);
-        dsc = tr(" Descent: %1%2").arg(val).arg(unit);
+        dsc = tr(", Descent: %1%2").arg(val).arg(unit);
 
         if(dt != NOFLOAT)
         {
@@ -628,10 +708,10 @@ QString CGisItemTrk::getInfoRange(const CTrackData::trkpt_t& pt1, const CTrackDa
     if(dt != NOFLOAT)
     {
         IUnit::self().seconds2time(dt, val, unit);
-        dsttme += tr(" Time: %1%2").arg(val).arg(unit);
+        dsttme += tr(", Time: %1%2").arg(val).arg(unit);
     }
 
-    return QString("%1 %2\n%3").arg(asc).arg(dsc).arg(dsttme);
+    return QString("%1%2\n%3").arg(asc).arg(dsc).arg(dsttme);
 }
 
 qint32 CGisItemTrk::getElevation(qint32 idx) const
@@ -684,21 +764,23 @@ bool CGisItemTrk::isRangeSelected() const
     return mouseRange1 != mouseRange2;
 }
 
-static inline void updateExtrema(CGisItemTrk::limits_t &extrema, qreal val)
+static inline void updateExtrema(CGisItemTrk::limits_t &extrema, qreal val, const QPointF& pos)
 {
     if(NOFLOAT != val)
     {
-        extrema = { qMin(extrema.min, val), qMax(extrema.max, val) };
+        extrema.setMin(val, pos);
+        extrema.setMax(val, pos);
     }
 }
 
 void CGisItemTrk::updateExtremaAndExtensions()
 {
     extrema = QHash<QString, limits_t>();
-    limits_t extremaSpeed    = { numeric_limits<qreal>::max(), numeric_limits<qreal>::lowest() };
-    limits_t extremaSlope    = { numeric_limits<qreal>::max(), numeric_limits<qreal>::lowest() };
-    limits_t extremaEle      = { numeric_limits<qreal>::max(), numeric_limits<qreal>::lowest() };
-    limits_t extremaProgress = { numeric_limits<qreal>::max(), numeric_limits<qreal>::lowest() };
+    limits_t extremaSpeed;
+    limits_t extremaSlope;
+    limits_t extremaEle;
+    limits_t extremaProgress;
+
 
     existingExtensions = QSet<QString>();
     QSet<QString> nonRealExtensions;
@@ -712,15 +794,20 @@ void CGisItemTrk::updateExtremaAndExtensions()
 
         existingExtensions.unite(pt.extensions.keys().toSet());
 
+        const QPointF& pos = {pt.lon, pt.lat};
         for(const QString &key : pt.extensions.keys())
         {
             bool isReal = false;
             qreal val = pt.extensions.value(key).toReal(&isReal);
 
+
             if(isReal)
             {
-                const limits_t &current = extrema.value(key, { numeric_limits<qreal>::max(), numeric_limits<qreal>::lowest() });
-                extrema[key] = { qMin(current.min, val), qMax(current.max, val) };
+                if(!extrema.contains(key))
+                {
+                    extrema[key] = limits_t();
+                }
+                updateExtrema(extrema[key], val, pos);
             }
             else
             {
@@ -728,10 +815,10 @@ void CGisItemTrk::updateExtremaAndExtensions()
             }
         }
 
-        updateExtrema(extremaSpeed,    pt.speed);
-        updateExtrema(extremaEle,      pt.ele);
-        updateExtrema(extremaSlope,    pt.slope1);
-        updateExtrema(extremaProgress, pt.distance);
+        updateExtrema(extremaSpeed,    pt.speed, pos);
+        updateExtrema(extremaEle,      pt.ele, pos);
+        updateExtrema(extremaSlope,    pt.slope1, pos);
+        updateExtrema(extremaProgress, pt.distance, pos);
     }
 
     if(extremaEle.min < extremaEle.max)
@@ -748,8 +835,9 @@ void CGisItemTrk::updateExtremaAndExtensions()
 
     if(numeric_limits<qreal>::max() != extremaSpeed.min)
     {
-        existingExtensions << CKnownExtension::internalSpeed;
-        extrema[CKnownExtension::internalSpeed] = extremaSpeed;
+        existingExtensions << CKnownExtension::internalSpeedDist;
+        existingExtensions << CKnownExtension::internalSpeedTime;
+        extrema[CKnownExtension::internalSpeedDist] = extremaSpeed;
     }
 
     if(numeric_limits<qreal>::max() != extremaProgress.min)
@@ -819,6 +907,7 @@ void CGisItemTrk::deriveSecondaryData()
 
     // reset all secondary data
     allValidFlags             = 0;
+    cntInvalidPoints          = 0;
     cntTotalPoints            = 0;
     cntVisiblePoints          = 0;
     timeStart                 = QDateTime();
@@ -860,6 +949,10 @@ void CGisItemTrk::deriveSecondaryData()
 
         // count only visible points to allValidFlags
         allValidFlags |= trkpt.valid;
+        if((trkpt.valid & 0xFFFF0000) != 0)
+        {
+            cntInvalidPoints++;
+        }
 
         trkpt.idxVisible = cntVisiblePoints++;
         lintrk << &trkpt;
@@ -883,17 +976,19 @@ void CGisItemTrk::deriveSecondaryData()
                 trkpt.ascent  = lastTrkpt->ascent;
                 trkpt.descent = lastTrkpt->descent;
 
-                if(qAbs(delta) > ASCENT_THRESHOLD)
+                if(qAbs(delta) >= ASCENT_THRESHOLD)
                 {
+                    const qint32 step = (delta/ASCENT_THRESHOLD)*ASCENT_THRESHOLD;
+
                     if(delta > 0)
                     {
-                        trkpt.ascent  += delta;
+                        trkpt.ascent  += step;
                     }
                     else
                     {
-                        trkpt.descent -= delta;
+                        trkpt.descent -= step;
                     }
-                    lastEle = trkpt.ele;
+                    lastEle += step;
                 }
             }
 
@@ -1353,7 +1448,7 @@ void CGisItemTrk::combine(const QList<IGisItem::key_t>& keys)
     trk1->history.events.clear();
 
     // copy the segments of all tracks to new track
-    CGisWidget& gis = CGisWidget::self();
+    CGisWorkspace& gis = CGisWorkspace::self();
     for(const IGisItem::key_t &key : keys)
     {
         CGisItemTrk * trk2 = dynamic_cast<CGisItemTrk*>(gis.getItemByKey(key));
@@ -1611,6 +1706,87 @@ void CGisItemTrk::drawItem(QPainter& p, const QPolygonF& viewport, QList<QRectF>
         drawColorized(p);
     }
     // -------------------------
+
+    // draw min/max labels
+    if(CMainWindow::self().isMinMaxTrackValues())
+    {
+        if(!keyUserFocus.item.isEmpty() && (key != keyUserFocus))
+        {
+            return;
+        }
+
+        for(const QString& key : extrema.keys())
+        {
+            if(key == CKnownExtension::internalProgress)
+            {
+                continue;
+            }
+
+            const limits_t& limit = extrema[key];
+            QPointF posMin = limit.posMin * DEG_TO_RAD;
+            QPointF posMax = limit.posMax * DEG_TO_RAD;
+
+            gis->convertRad2Px(posMin);
+            gis->convertRad2Px(posMax);
+
+            p.setPen(Qt::white);
+            p.setBrush(Qt::darkGreen);
+            p.drawEllipse(posMin, 5, 5);
+            p.setBrush(Qt::darkRed);
+            p.drawEllipse(posMax, 5, 5);
+        }
+    }
+}
+
+static bool doesOverlap(const QList<QRectF>& blockedAreas, const QRectF& rect)
+{
+    for(const QRectF& r : blockedAreas)
+    {
+        if(r.intersects(rect))
+        {
+            return true;
+        }
+    }
+    return false;
+}
+
+void CGisItemTrk::drawLimitLabels(limit_type_e type, const QString& label, const QPointF& pos, QPainter& p, const QFontMetricsF& fm, QList<QRectF>& blockedAreas)
+{
+    const QString& fullLabel = (type == eLimitTypeMin ? tr("min.") : tr("max.")) + " " + label;
+    QRectF rect = fm.boundingRect(fullLabel);
+    rect.moveBottomLeft(pos.toPoint() + QPoint(10,-10));
+    rect.adjust(-4,-2,4,2);
+
+    qint32 baseWidth    = 10;
+    qint32 basePos      = 10;
+
+
+    if(doesOverlap(blockedAreas, rect))
+    {
+        rect.moveBottomRight(pos.toPoint() + QPoint(-10,-10));
+        basePos = rect.width() - 10;
+
+        if(doesOverlap(blockedAreas, rect))
+        {
+            rect.moveTopLeft(pos.toPoint() + QPoint(10,10));
+            basePos = 10;
+
+            if(doesOverlap(blockedAreas, rect))
+            {
+                rect.moveTopRight(pos.toPoint() + QPoint(-10,10));
+                basePos = rect.width() - 10;
+
+                if(doesOverlap(blockedAreas, rect))
+                {
+                    return;
+                }
+            }
+        }
+    }
+
+    CDraw::bubble(p, rect.toRect(), pos.toPoint(), baseWidth, basePos, (key == keyUserFocus) ? CDraw::penBorderRed : CDraw::penBorderGray);
+    CDraw::text(fullLabel, p, rect.toRect(), type == eLimitTypeMin ? Qt::darkGreen : Qt::darkRed);
+    blockedAreas << rect;
 }
 
 void CGisItemTrk::setPen(QPainter& p, QPen& pen, quint32 flag) const
@@ -1914,9 +2090,39 @@ void CGisItemTrk::drawItem(QPainter& p, const QRectF& viewport, CGisDraw * gis)
     drawRange(p);
 }
 
-void CGisItemTrk::drawLabel(QPainter&, const QPolygonF&, QList<QRectF>&, const QFontMetricsF&, CGisDraw*)
+void CGisItemTrk::drawLabel(QPainter& p, const QPolygonF&, QList<QRectF>& blockedAreas, const QFontMetricsF& fm, CGisDraw* gis)
 {
-    // tracks don't have labels
+    if(!keyUserFocus.item.isEmpty() && (key != keyUserFocus))
+    {
+        return;
+    }
+
+    if(CMainWindow::self().isMinMaxTrackValues())
+    {
+        for(const QString& key : extrema.keys())
+        {
+            const CKnownExtension& ext = CKnownExtension::get(key);
+            const limits_t& limit = extrema[key];
+            QPointF posMin = limit.posMin * DEG_TO_RAD;
+            QPointF posMax = limit.posMax * DEG_TO_RAD;
+
+            gis->convertRad2Px(posMin);
+            gis->convertRad2Px(posMax);
+
+            QString labelMin = ext.toString(limit.min, true, key);
+            QString labelMax = ext.toString(limit.max, true, key);
+
+            if(!labelMin.isEmpty())
+            {
+                drawLimitLabels(eLimitTypeMin, labelMin, posMin, p, fm, blockedAreas);
+            }
+
+            if(!labelMax.isEmpty())
+            {
+                drawLimitLabels(eLimitTypeMax, labelMax, posMax, p, fm, blockedAreas);
+            }
+        }
+    }
 }
 
 
