@@ -32,6 +32,7 @@
 #include <functional>
 #include <interpolation.h>
 
+using std::numeric_limits;
 
 class QDomNode;
 class IGisProject;
@@ -96,12 +97,12 @@ public:
     CGisItemTrk(quint64 id, QSqlDatabase& db, IGisProject * project);
 
     /** @brief Clone QLandkarte GT track */
-    CGisItemTrk(const CQlgtTrack& trk1);
+    CGisItemTrk(const CQlgtTrack& trk1, IGisProject *project = nullptr);
 
     /** @brief Load track from file (e.g. TwoNav *trk) */
     CGisItemTrk(const QString& filename, IGisProject * project);
 
-    CGisItemTrk(const IQlgtOverlay& ovl);
+    CGisItemTrk(const IQlgtOverlay& ovl, IGisProject *project = nullptr);
 
     /**
        @brief Creates a new track via provided trkdata
@@ -183,7 +184,7 @@ public:
     /// returns "true" when trk has no time-related invalid points
     bool isTrkTimeValid() { return (allValidFlags & CTrackData::trkpt_t::eInvalidTime) == 0;  }
 
-    QDateTime getTimestamp() const override { return getTimeStart(); }
+    QDateTime getTimestamp() const override {return getTimeStart(); }
 
     /// get the track color as index into the Garmin color table
     int getColorIdx() const { return colorIdx; }
@@ -196,7 +197,7 @@ public:
        @param showName  if true the track name is shown
        @return
      */
-    QString getInfo(bool showName, bool showFullText) const override;
+    QString getInfo(quint32 feature) const override;
     /// get a summary of a selected range
     QString getInfoRange() const;
     /// get a summary of a selected range defined by two track points
@@ -206,6 +207,8 @@ public:
     /// get a progress summary for a selected track point
     QString getInfoProgress(const CTrackData::trkpt_t& pt) const;
 
+    QString getInfoLimits() const;
+
     quint32 getTotalElapsedSeconds()       const { return totalElapsedSeconds;       }
     quint32 getTotalElapsedSecondsMoving() const { return totalElapsedSecondsMoving; }
 
@@ -289,7 +292,6 @@ private:
     /**@}*/
 
 
-
 public:
     bool isRangeSelected() const;
 
@@ -338,7 +340,7 @@ public:
 
     void drawItem(QPainter& p, const QPolygonF& viewport, QList<QRectF>& blockedAreas, CGisDraw * gis) override;
     void drawItem(QPainter& p, const QRectF& viewport, CGisDraw * gis) override;
-    void drawLabel(QPainter&, const QPolygonF&, QList<QRectF>&, const QFontMetricsF&, CGisDraw*) override;
+    void drawLabel(QPainter&p, const QPolygonF&, QList<QRectF>&blockedAreas, const QFontMetricsF&fm, CGisDraw*gis) override;
     void drawHighlight(QPainter& p) override;
     void drawRange(QPainter& p);
 
@@ -597,8 +599,29 @@ private:
 public:
     struct limits_t
     {
-        qreal min;
-        qreal max;
+        void setMin(qreal val, const QPointF& pos)
+        {
+            if(min > val)
+            {
+                min     = val;
+                posMin  = pos;
+            }
+        }
+
+        void setMax(qreal val, const QPointF& pos)
+        {
+            if(max < val)
+            {
+                max     = val;
+                posMax  = pos;
+            }
+        }
+
+        qreal min     = numeric_limits<qreal>::max();
+        QPointF posMin  = NOPOINTF;
+
+        qreal max     = numeric_limits<qreal>::lowest();
+        QPointF posMax  = NOPOINTF;
     };
     /**@}*/
 
@@ -607,6 +630,13 @@ private:
     QHash<QString, limits_t> extrema;
     void updateExtremaAndExtensions();
 
+    enum limit_type_e
+    {
+        eLimitTypeMin
+        , eLimitTypeMax
+    };
+    void drawLimitLabels(limit_type_e type, const QString &label, const QPointF& pos, QPainter& p, const QFontMetricsF &fm, QList<QRectF> &blockedAreas);
+
     /**
        @brief Tell the point of focus to all plots and the detail dialog
 
@@ -717,7 +747,8 @@ private:
        \defgroup TrackStatistics Some statistical values over the complete track
      */
     /**@{*/
-    quint32 allValidFlags = 0;
+    quint32 allValidFlags   = 0;
+    qint32 cntInvalidPoints = 0;
     qint32 cntTotalPoints   = 0;
     qint32 cntVisiblePoints = 0;
     QDateTime timeStart;
