@@ -26,11 +26,7 @@ CFilterDelete::CFilterDelete(CGisItemTrk &trk, QWidget *parent)
 {
     setupUi(this);
 
-    connect(toolApply, SIGNAL(clicked()), this, SLOT(slotApply()));
-}
-
-CFilterDelete::~CFilterDelete()
-{
+    connect(toolApply, &QToolButton::clicked, this, &CFilterDelete::slotApply);
 }
 
 void CFilterDelete::slotApply()
