@@ -16,9 +16,9 @@
 
 **********************************************************************************************/
 
-#include "gis/trk/filter/CFilterInvalid.h"
 #include "canvas/CCanvas.h"
 #include "gis/trk/CGisItemTrk.h"
+#include "gis/trk/filter/CFilterInvalid.h"
 
 CFilterInvalid::CFilterInvalid(CGisItemTrk &trk, QWidget *parent)
     : QWidget(parent)
@@ -27,16 +27,12 @@ CFilterInvalid::CFilterInvalid(CGisItemTrk &trk, QWidget *parent)
 {
     setupUi(this);
 
-    connect(toolApply, SIGNAL(clicked()), this, SLOT(slotApply()));
-}
-
-CFilterInvalid::~CFilterInvalid()
-{
+    connect(toolApply, &QToolButton::clicked, this, &CFilterInvalid::slotApply);
 }
 
 void CFilterInvalid::slotApply()
 {
     CCanvas::setOverrideCursor(Qt::WaitCursor, "CFilterInvalid");
-    trk.filterRemoveNullPoints();
+    trk.filterRemoveInvalidPoints();
     CCanvas::restoreOverrideCursor("CFilterInvalid");
 }
