@@ -29,14 +29,9 @@ CFilterNewDate::CFilterNewDate(CGisItemTrk &trk, QWidget *parent)
     labelTimeZone->setText(QDateTime::currentDateTime().timeZone().abbreviation(QDateTime::currentDateTime()));
     dateTimeEdit->setDateTime(QDateTime::currentDateTime());
 
-    connect(toolApply, SIGNAL(clicked()), this, SLOT(slotApply()));
+    connect(toolApply, &QToolButton::clicked, this, &CFilterNewDate::slotApply);
 }
 
-CFilterNewDate::~CFilterNewDate()
-{
-}
-
-
 void CFilterNewDate::slotApply()
 {
     CCanvas::setOverrideCursor(Qt::WaitCursor,"CFilterNewDate");
