@@ -33,7 +33,7 @@ CFilterOffsetElevation::CFilterOffsetElevation(CGisItemTrk &trk, QWidget *parent
     SETTINGS;
     spinBox->setValue(cfg.value("TrackDetails/Filter/OffsetElevation/offset",0).toInt());
 
-    connect(toolApply, SIGNAL(clicked()), this, SLOT(slotApply()));
+    connect(toolApply, &QToolButton::clicked, this, &CFilterOffsetElevation::slotApply);
 }
 
 CFilterOffsetElevation::~CFilterOffsetElevation()
