@@ -31,7 +31,7 @@ CFilterReplaceElevation::CFilterReplaceElevation(CGisItemTrk &trk, QWidget *pare
 
 void CFilterReplaceElevation::slotApply()
 {
-    CCanvas::setOverrideCursor(Qt::WaitCursor,"CFilterMedian");
+    CCanvas::setOverrideCursor(Qt::WaitCursor,"CFilterReplaceElevation");
     trk.filterReplaceElevation();
-    CCanvas::restoreOverrideCursor("CFilterMedian");
+    CCanvas::restoreOverrideCursor("CFilterReplaceElevation");
 }
