@@ -1,5 +1,6 @@
 /**********************************************************************************************
     Copyright (C) 2014 Oliver Eichler oliver.eichler@gmx.de
+    Copyright (C) 2017 Norbert Truchsess norbert.truchsess@t-online.de
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -44,6 +45,9 @@ private slots:
     void slotMove();
     void slotProj();
     void slotBubble();
+    void slotDeleteRadius();
+    void slotNogoArea();
+    void slotEditRadius();
 
 private:
     IGisItem::key_t key;
