@@ -31,7 +31,7 @@ public:
     virtual ~CLinksDialog();
 
 public slots:
-    void accept();
+    void accept() override;
 
 private slots:
     void slotAddLink();
