@@ -37,9 +37,9 @@ signals:
     void sigChanged();
 
 protected:
-    void dragEnterEvent(QDragEnterEvent * e);
-    void dragMoveEvent (QDragMoveEvent  * e );
-    void dropEvent ( QDropEvent  * e );
+    void dragEnterEvent(QDragEnterEvent *e) override;
+    void dragMoveEvent(QDragMoveEvent  *e) override;
+    void dropEvent(QDropEvent      *e) override;
 };
 
 #include "ui_IMapList.h"
@@ -63,13 +63,18 @@ public:
 
 signals:
     void sigChanged();
+    void sigSetupMapPath();
 
 public slots:
     static void slotMapHonk();
 
 private slots:
     void slotActivate();
+    void slotMoveUp();
+    void slotMoveDown();
+    void slotReloadMaps();
     void slotContextMenu(const QPoint &point);
+    void slotLinkActivated(const QString& link);
 
 private:
     QMenu * menu;
