@@ -19,6 +19,7 @@
 #ifndef IMAP_H
 #define IMAP_H
 
+#include "canvas/IDrawContext.h"
 #include "canvas/IDrawObject.h"
 #include <QImage>
 #include <QMutex>
@@ -253,7 +254,7 @@ protected:
     bool showPolygons  = true; //< vector maps only: hide/show polygons
     bool showPolylines = true; //< vector maps only: hide/show polylines
     bool showPOIs      = true; //< vector maps only: hide/show point of interest
-    qint32 adjustDetailLevel = 0; //< vector maps only: alter threshold to show deatils.
+    qint32 adjustDetailLevel = 0; //< vector maps only: alter threshold to show details.
 
     QString cachePath;            //< streaming map only: path to cached tiles
     qint32 cacheSizeMB     = 100; //< streaming map only: maximum size of all tiles in cache [MByte]
