@@ -27,6 +27,6 @@ public:
     CGarminStrTbl8(const quint16 codepage, const quint8 mask, QObject * parent);
     virtual ~CGarminStrTbl8();
 
-    void get(CFileExt& file, quint32 offset, type_e t, QStringList& info);
+    void get(CFileExt& file, quint32 offset, type_e t, QStringList& info) override;
 };
 #endif                           //CGARMINSTRTBL8_H
