@@ -51,7 +51,8 @@ void CGarminStrTblUtf8::get(CFileExt& file, quint32 offset, type_e t, QStringLis
     readFile(file, offsetLBL1 + offset, size, data);
     char * lbl = data.data();
 
-    char * pBuffer = buffer; *pBuffer = 0;
+    char * pBuffer = buffer;
+    *pBuffer = 0;
     while(*lbl != 0)
     {
         if((unsigned)*lbl >= 0x1B && (unsigned)*lbl <= 0x1F)
@@ -60,7 +61,8 @@ void CGarminStrTblUtf8::get(CFileExt& file, quint32 offset, type_e t, QStringLis
             if(strlen(buffer))
             {
                 labels << codec->toUnicode(buffer);
-                pBuffer = buffer; *pBuffer = 0;
+                pBuffer = buffer;
+                *pBuffer = 0;
             }
             ++lbl;
             continue;
