@@ -26,6 +26,6 @@ public:
     CGarminStrTblUtf8(const quint16 codepage, const quint8 mask, QObject * parent);
     virtual ~CGarminStrTblUtf8();
 
-    void get(CFileExt& file, quint32 offset, type_e t, QStringList& info);
+    void get(CFileExt& file, quint32 offset, type_e t, QStringList& info) override;
 };
-#endif                           //CGARMINSTRTBLUTF8_H
+#endif //CGARMINSTRTBLUTF8_H
