@@ -18,7 +18,7 @@
 
 #include "CMainWindow.h"
 #include "canvas/CCanvas.h"
-#include "gis/CGisWidget.h"
+#include "gis/CGisWorkspace.h"
 #include "gis/ovl/CGisItemOvlArea.h"
 #include "mouse/CMouseEditArea.h"
 
@@ -58,7 +58,7 @@ void CMouseEditArea::drawLine(const QPolygonF &l, const QColor color, int width,
 
 IGisLine * CMouseEditArea::getGisLine() const
 {
-    return dynamic_cast<CGisItemOvlArea*>(CGisWidget::self().getItemByKey(key));
+    return dynamic_cast<CGisItemOvlArea*>(CGisWorkspace::self().getItemByKey(key));
 }
 
 void CMouseEditArea::slotAbort()
@@ -75,8 +75,6 @@ void CMouseEditArea::slotCopyToOrig()
 
 void CMouseEditArea::slotCopyToNew()
 {
-    QMutexLocker lock(&IGisItem::mutexItems);
-
     canvas->reportStatus(key.item,"");
 
     if(points.size() < 3)
@@ -87,7 +85,7 @@ void CMouseEditArea::slotCopyToNew()
     IGisProject * project = nullptr;
 
     QString name;
-    CGisItemOvlArea * area = dynamic_cast<CGisItemOvlArea*>(CGisWidget::self().getItemByKey(key));
+    CGisItemOvlArea * area = dynamic_cast<CGisItemOvlArea*>(CGisWorkspace::self().getItemByKey(key));
     if(area != nullptr)
     {
         name = area->getName();
@@ -98,7 +96,10 @@ void CMouseEditArea::slotCopyToNew()
         return;
     }
 
-    new CGisItemOvlArea(points, name, project, NOIDX);
+    {
+        QMutexLocker lock(&IGisItem::mutexItems);
+        new CGisItemOvlArea(points, name, project, NOIDX);
+    }
 
     canvas->resetMouse();
     canvas->slotTriggerCompleteUpdate(CCanvas::eRedrawGis);
