@@ -31,16 +31,16 @@ public:
     CMouseEditTrk(CGisItemTrk &trk, CGisDraw * gis, CCanvas * parent);
     virtual ~CMouseEditTrk();
 
-    void mousePressEvent(QMouseEvent * e);
+    void mousePressEvent(QMouseEvent * e) override;
 
 protected slots:
-    void slotAbort();
-    void slotCopyToNew();
-    void slotCopyToOrig();
+    void slotAbort()      override;
+    void slotCopyToNew()  override;
+    void slotCopyToOrig() override;
 
 
 protected:
-    IGisLine * getGisLine();
+    IGisLine* getGisLine() const override;
     bool isNewLine = true;
 };
 
