@@ -39,10 +39,14 @@ public:
     void mouseMoveEvent(QMouseEvent *e) override;
     void mouseReleaseEvent(QMouseEvent *e) override;
     void wheelEvent(QWheelEvent *e) override;
+    void afterMouseLostEvent(QMouseEvent *e) override;
 
 private:
-    IGisItem::key_t key;
-    QPointF origPos;
+    const IGisItem::key_t key;
+    const QPointF origPos;
+    const qreal radius;
+    const bool avoid;
+
     QPointF newPos;
     QPointF focus;
     QPixmap icon;
