@@ -1,5 +1,6 @@
 /**********************************************************************************************
     Copyright (C) 2014 Oliver Eichler oliver.eichler@gmx.de
+    Copyright (C) 2017 Norbert Truchsess norbert.truchsess@t-online.de
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -46,6 +47,7 @@ public:
     void mouseDoubleClickEvent(QMouseEvent *e) override;
     void wheelEvent(QWheelEvent * e) override;
     void keyPressEvent(QKeyEvent * e) override;
+    void afterMouseLostEvent(QMouseEvent *e) override;
 
 private slots:
     void slotAddPoi()           const;
@@ -59,7 +61,7 @@ private slots:
 
 private:
     bool setScreenOption(const QPoint& pt, IGisItem * item);
-
+    void scrollToItem(IGisItem * item);
 protected:
     void stopTracking() const;
     void resetState();
