@@ -17,7 +17,7 @@
 **********************************************************************************************/
 
 #include "gis/CGisDraw.h"
-#include "gis/CGisWidget.h"
+#include "gis/CGisWorkspace.h"
 #include "helpers/CWptIconDialog.h"
 #include "mouse/CMouseSelect.h"
 #include "mouse/CScrOptSelect.h"
@@ -37,7 +37,8 @@ CMouseSelect::CMouseSelect(CGisDraw *gis, CCanvas *parent)
     connect(scrOptSelect->toolCopy,         &QToolButton::clicked, this, &CMouseSelect::slotCopy);
     connect(scrOptSelect->toolRoute,        &QToolButton::clicked, this, &CMouseSelect::slotRoute);
     connect(scrOptSelect->toolSymWpt,       &QToolButton::clicked, this, &CMouseSelect::slotSymWpt);
-    connect(scrOptSelect->toolCombineTracks, &QToolButton::clicked, this, &CMouseSelect::slotCombine);
+    connect(scrOptSelect->toolCombineTrk,   &QToolButton::clicked, this, &CMouseSelect::slotCombineTrk);
+    connect(scrOptSelect->toolActivityTrk,  &QToolButton::clicked, this, &CMouseSelect::slotActivityTrk);
     connect(scrOptSelect->toolDelete,       &QToolButton::clicked, this, &CMouseSelect::slotDelete);
 }
 
@@ -57,7 +58,7 @@ void CMouseSelect::findItems(QList<IGisItem*>& items)
     {
         if(!itemKeys.isEmpty())
         {
-            CGisWidget::self().getItemsByKeys(itemKeys, items);
+            CGisWorkspace::self().getItemsByKeys(itemKeys, items);
         }
     }
     else
@@ -66,7 +67,7 @@ void CMouseSelect::findItems(QList<IGisItem*>& items)
 
         QRectF area;
         rectRad2Px(rectSelection, area);
-        CGisWidget::self().getItemsByArea(area, modeSelection, items);
+        CGisWorkspace::self().getItemsByArea(area, modeSelection, items);
 
         cntWpt = 0;
         cntTrk = 0;
@@ -125,7 +126,8 @@ void CMouseSelect::findItems(QList<IGisItem*>& items)
     scrOptSelect->frameFunction->setDisabled(items.isEmpty());
     scrOptSelect->toolSymWpt->setEnabled(cntWpt);
     scrOptSelect->toolRoute->setEnabled(cntWpt > 1);
-    scrOptSelect->toolCombineTracks->setEnabled(cntTrk > 1);
+    scrOptSelect->toolCombineTrk->setEnabled(cntTrk > 1);
+    scrOptSelect->toolActivityTrk->setEnabled(cntTrk > 0);
 }
 
 void CMouseSelect::draw(QPainter& p, CCanvas::redraw_e needsRedraw, const QRect &rect)
@@ -150,25 +152,31 @@ void CMouseSelect::draw(QPainter& p, CCanvas::redraw_e needsRedraw, const QRect
 
 void CMouseSelect::slotCopy() const
 {
-    CGisWidget::self().copyItemsByKey(itemKeys);
+    CGisWorkspace::self().copyItemsByKey(itemKeys);
     canvas->resetMouse();
 }
 
 void CMouseSelect::slotDelete() const
 {
-    CGisWidget::self().delItemsByKey(itemKeys);
+    CGisWorkspace::self().delItemsByKey(itemKeys);
     canvas->resetMouse();
 }
 
 void CMouseSelect::slotRoute() const
 {
-    CGisWidget::self().makeRteFromWpt(itemKeys);
+    CGisWorkspace::self().makeRteFromWpt(itemKeys);
     canvas->resetMouse();
 }
 
-void CMouseSelect::slotCombine() const
+void CMouseSelect::slotCombineTrk() const
 {
-    CGisWidget::self().combineTrkByKey(itemKeys, itemKeys);
+    CGisWorkspace::self().combineTrkByKey(itemKeys, itemKeys);
+    canvas->resetMouse();
+}
+
+void CMouseSelect::slotActivityTrk() const
+{
+    CGisWorkspace::self().activityTrkByKey(itemKeys);
     canvas->resetMouse();
 }
 
@@ -181,6 +189,6 @@ void CMouseSelect::slotSymWpt() const
         return;
     }
 
-    CGisWidget::self().changeWptSymByKey(itemKeys, tb.objectName());
+    CGisWorkspace::self().changeWptSymByKey(itemKeys, tb.objectName());
     canvas->resetMouse();
 }
