@@ -1,5 +1,6 @@
 /**********************************************************************************************
     Copyright (C) 2014 Oliver Eichler oliver.eichler@gmx.de
+    Copyright (C) 2017 Norbert Truchsess norbert.truchsess@t-online.de
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -26,6 +27,7 @@
 #include <QPointer>
 
 class QMouseEvent;
+class QPinchGesture;
 class QWheelEvent;
 class QTimer;
 class CGisDraw;
@@ -44,10 +46,18 @@ public:
     virtual void mouseDoubleClickEvent(QMouseEvent *e)
     {
     }
-    virtual void wheelEvent(QWheelEvent *e) = 0;
+    virtual void wheelEvent(QWheelEvent *e)
+    {
+    }
     virtual void keyPressEvent(QKeyEvent *e)
     {
     }
+    virtual void pinchGestureEvent(QPinchGesture *e)
+    {
+    }
+    virtual void afterMouseLostEvent(QMouseEvent *e)
+    {
+    }
 
     /// the current mouse cursor
     /**
@@ -66,6 +76,9 @@ public:
 
     virtual void setMouseTracking(bool enabled);
 
+    const static int longButtonPressTimeout = 400;
+    const static int minimalMouseMovingDistance = 4;
+
 protected:
     /// the functions mouse icon
     QCursor cursor;
