@@ -16,6 +16,7 @@
 
 **********************************************************************************************/
 
+#include "gis/CGisWorkspace.h"
 #include "helpers/CDraw.h"
 #include "mouse/IMouse.h"
 #include "mouse/IScrOpt.h"
@@ -36,6 +37,7 @@ IScrOpt::~IScrOpt()
     {
         CCanvas::setOverrideCursor(*mouse,"IScrOpt::~IScrOpt");
     }
+    CGisWorkspace::self().slotWksItemSelectionReset();
 }
 
 void IScrOpt::mouseMoveEvent(QMouseEvent * e)
