@@ -27,16 +27,14 @@ public:
     CLineOpAddPoint(SGisLine& points, CGisDraw *gis, CCanvas *canvas, IMouseEditLine *parent);
     virtual ~CLineOpAddPoint();
 
-    void mousePressEventEx(QMouseEvent *e) override;
-    void mouseMoveEventEx(QMouseEvent *e) override;
-    void mouseReleaseEventEx(QMouseEvent *e) override
+    void mousePressEventEx(QMouseEvent *e) override
     {
     }
+    void mouseMoveEventEx(QMouseEvent *e) override;
+    void mouseReleaseEventEx(QMouseEvent *e) override;
 
     void drawFg(QPainter& p) override;
 
-    void canvasPanned(QPointF pos) override;
-
     void append();
 
     bool abortStep() override;
