@@ -27,15 +27,13 @@ public:
     CLineOpDeletePoint(SGisLine& points, CGisDraw *gis, CCanvas *canvas, IMouseEditLine *parent);
     virtual ~CLineOpDeletePoint();
 
-    void mousePressEventEx(QMouseEvent * e)
+    void mousePressEventEx(QMouseEvent*) override
     {
     }
-    void mouseMoveEventEx(QMouseEvent * e);
-    void mouseReleaseEventEx(QMouseEvent *e);
+    void mouseMoveEventEx(QMouseEvent *e) override;
+    void mouseReleaseEventEx(QMouseEvent *e) override;
 
-    void drawFg(QPainter& p);
-
-private:
+    void drawFg(QPainter& p) override;
 };
 
 #endif //CLINEOPDELETEPOINT_H
