@@ -64,6 +64,8 @@ public:
     void mouseReleaseEvent(QMouseEvent *e) override;
     void wheelEvent(QWheelEvent *e) override;
     void keyPressEvent(QKeyEvent *e) override;
+    void pinchGestureEvent(QPinchGesture *e) override;
+    void afterMouseLostEvent(QMouseEvent *e) override;
 
     void abortStep();
 
