@@ -20,22 +20,17 @@
 
 #include <QtWidgets>
 
-CPlotAxisTime::CPlotAxisTime(QObject * parent)
-    : CPlotAxis(parent)
+void CPlotAxisTime::calc() /* override */
 {
-}
+    int dSec  = usedMax - usedMin;
+    ticStart  = usedMin;
 
-
-CPlotAxisTime::~CPlotAxisTime()
-{
-}
-
-
-void CPlotAxisTime::calc()
-{
-    int dSec    = usedMax - usedMin;
-    ticStart    = usedMin;
-    strFormat   = "hh:mm:ss";
+    // abort if the xRange has a length of 0
+    if(0 == dSec)
+    {
+        valid = false;
+        return;
+    }
 
     if(dSec < 0)
     {
@@ -103,12 +98,7 @@ void CPlotAxisTime::calc()
     if ( autoscale )
     {
         usedMin = qFloor( usedMin / interval ) * interval;
-        usedMax = qCeil( usedMax / interval ) * interval;
-    }
-    else
-    {
-        usedMin = usedMin;
-        usedMax = usedMax;
+        usedMax = qCeil(  usedMax / interval ) * interval;
     }
 
     int t1 = ( int )( usedMin / interval + 0.5);
@@ -122,7 +112,7 @@ void CPlotAxisTime::calc()
 }
 
 
-const CPlotAxis::tic_t* CPlotAxisTime::ticmark( const tic_t * t )
+const CPlotAxis::tic_t* CPlotAxisTime::ticmark( const tic_t * t ) /* override */
 {
     const tic_t * _tic_ = CPlotAxis::ticmark(t);
     if(_tic_)
