@@ -266,7 +266,7 @@ quint64 CQmsDb::store(IGisItem& item)
     query.bindValue(":icon",    buffer.data());
     query.bindValue(":name",    item.getName());
     query.bindValue(":date",    item.getTimestamp());
-    query.bindValue(":comment", item.getInfo(true, true));
+    query.bindValue(":comment", item.getInfo(IGisItem::eFeatureShowName|IGisItem::eFeatureShowFullText));
     query.bindValue(":data", data);
     query.bindValue(":hash", item.getHash());
     QUERY_EXEC(return 0);
