@@ -36,6 +36,7 @@ CRoutinoDatabaseBuilder::CRoutinoDatabaseBuilder(QWidget * parent)
     connect(toolTargetPath,   &QToolButton::clicked,   this, &CRoutinoDatabaseBuilder::slotSelectTargetPath);
     connect(pushStart,        &QPushButton::clicked,   this, &CRoutinoDatabaseBuilder::slotStart);
     connect(lineTargetPrefix, &QLineEdit::textChanged, this, &CRoutinoDatabaseBuilder::enabelStartButton);
+    connect(labelHelp,        &QLabel::linkActivated,  this, &CRoutinoDatabaseBuilder::slotLinkActivated);
 
     pushStart->setDisabled(true);
 
@@ -183,3 +184,8 @@ void CRoutinoDatabaseBuilder::finished(int exitCode, QProcess::ExitStatus status
         cmd.start("planetsplitter", args);
     }
 }
+
+void CRoutinoDatabaseBuilder::slotLinkActivated(const QUrl& url)
+{
+    QDesktopServices::openUrl(url);
+}
