@@ -23,14 +23,19 @@
 
 class CUnitImperial : public IUnit
 {
-    Q_OBJECT;
 public:
     CUnitImperial(QObject * parent);
-    virtual ~CUnitImperial();
+    virtual ~CUnitImperial() = default;
 
-    void meter2elevation(qreal meter, QString& val, QString& unit);
-    void meter2distance(qreal meter, QString& val, QString& unit);
-    void meter2area(qreal meter, QString& val, QString& unit);
-    qreal elevation2meter(const QString& val);
+    void meter2elevation(qreal meter, QString& val, QString& unit) const override;
+    void meter2distance(qreal meter, QString& val, QString& unit) const override;
+    void meter2area(qreal meter, QString& val, QString& unit) const override;
+    qreal elevation2meter(const QString& val) const override;
+    void meter2unit(qreal meter, qreal& scale, QString&  unit) const override;
+
+private:
+    static const qreal footPerMeter;
+    static const qreal milePerMeter;
+    static const qreal meterPerSecToMilePerHour;
 };
-#endif                           //CUNITIMPERIAL_H
+#endif //CUNITIMPERIAL_H
