@@ -34,6 +34,8 @@ IUnit::coord_format_e IUnit::coordFormat = IUnit::eCoordFormat1;
 QByteArray IUnit::timeZone = "UTC";
 bool IUnit::useShortFormat = false;
 
+IUnit::slope_mode_e IUnit::slopeMode = IUnit::eSlopeDegrees;
+
 const char * IUnit::tblTimezone[] =
 {
     "Africa/Abidjan",
@@ -440,13 +442,41 @@ IUnit::IUnit(const type_e &type, const QString& baseunit, const qreal basefactor
     , speedfactor(speedfactor)
 {
     //there can be only one...
-    if(nullptr != m_self)
-    {
-        delete m_self;
-    }
+    delete m_self;
     m_self = this;
 }
 
+void IUnit::slope2string(qreal slope, QString &val, QString &unit)
+{
+    switch(slopeMode)
+    {
+    case eSlopeDegrees:
+        val.sprintf("%.1f", slope);
+        unit = "°";
+        break;
+
+    case eSlopePercent:
+        val.sprintf("%.0f", qTan(qDegreesToRadians(slope))*100.0);
+        unit = "%";
+        break;
+    }
+}
+
+void IUnit::slope2unit(qreal slope, qreal &val, QString &unit)
+{
+    switch(slopeMode)
+    {
+    case eSlopeDegrees:
+        val = slope;
+        unit = "°";
+        break;
+
+    case eSlopePercent:
+        val = qTan(qDegreesToRadians(slope))*100.0;
+        unit = "%";
+        break;
+    }
+}
 
 void IUnit::setUnitType(type_e t, QObject * parent)
 {
@@ -509,6 +539,7 @@ QDateTime IUnit::parseTimestamp(const QString &timetext, int& tzoffset)
     int i;
 
     tzoffset = 0;
+    bool applyTzOffset = false;
 
     QString format = "yyyy-MM-dd'T'hh:mm:ss";
 
@@ -529,7 +560,9 @@ QDateTime IUnit::parseTimestamp(const QString &timetext, int& tzoffset)
     if (timetext.indexOf("Z") != NOIDX)
     {
         format += "'Z'";
+        applyTzOffset = true;
     }
+
     else if ((i = tzRE.indexIn(timetext)) != NOIDX)
     {
         // trailing timezone offset [-+]HH:MM present
@@ -555,10 +588,19 @@ QDateTime IUnit::parseTimestamp(const QString &timetext, int& tzoffset)
             tzoffset = 60 * offsetHours + offsetMinutes;
         }
         tzoffset *= 60;          // seconds
+        applyTzOffset = true;
     }
 
     QDateTime datetime = QDateTime::fromString(timetext, format);
-    datetime.setOffsetFromUtc(tzoffset);
+
+    if (applyTzOffset)
+    {
+        datetime.setOffsetFromUtc(tzoffset);
+    }
+    else
+    {   // if timetext has no 'Z' and no [-+]HH:MM then this is local time then simply switch to UTC without applying any offset
+        datetime = datetime.toUTC();
+    }
 
     return datetime;
 }
