@@ -37,9 +37,9 @@ public:
     void setUnit(const QString &unit);
 
     void updateData() override;
-    void setMouseFocus(const CGisItemTrk::trkpt_t *pt) override;
-    void setMouseRangeFocus(const CGisItemTrk::trkpt_t *pt1, const CGisItemTrk::trkpt_t *pt2) override {}
-    void setMouseClickFocus(const CGisItemTrk::trkpt_t *pt) override {}
+    void setMouseFocus(const CTrackData::trkpt_t *pt) override;
+    void setMouseRangeFocus(const CTrackData::trkpt_t *pt1, const CTrackData::trkpt_t *pt2) override {}
+    void setMouseClickFocus(const CTrackData::trkpt_t *pt) override {}
 
 
 protected:
